@@ -5,11 +5,9 @@ Base class for UML model elements.
 
 __all__ = [ 'Element' ]
 
-import types, mutex
-from zope import component
-from event import ElementDeleteEvent
+import threading
 import uuid
-from properties import umlproperty, association
+from properties import umlproperty
 
 
 class Element(object):
@@ -33,7 +31,7 @@ class Element(object):
         self._id = id or (id is not False and str(uuid.uuid1()) or False)
         # The factory this element belongs to.
         self._factory = factory
-        self.__in_unlink = mutex.mutex()
+        self._unlink_lock = threading.Lock()
 
 
     id = property(lambda self: self._id, doc='Id')
@@ -87,18 +85,25 @@ class Element(object):
 
 
     def unlink(self):
-        """
-        Unlink the element. All the elements references are destroyed.
-        """
-        # Uses a mutex to make sure it is not called recursively
-        if self.__in_unlink.testandset():
-            try:
-                for prop in self.umlproperties():
-                    prop.unlink(self)
-                component.handle(ElementDeleteEvent(self._factory, self))
-            finally:
-                self.__in_unlink.unlock()
-
+        
+        """Unlink the element. All the elements references are destroyed.
+        
+        The unlink lock is acquired while unlinking this elements properties
+        to avoid recursion problems."""
+        
+        if self._unlink_lock.locked():
+            
+            return
+        
+        with self._unlink_lock:
+            
+            for prop in self.umlproperties():
+                
+                prop.unlink(self)
+                
+            if self._factory:
+            
+                self._factory._unlink_element(self)
 
     # OCL methods: (from SMW by Ivan Porres (http://www.abo.fi/~iporres/smw))
 
