@@ -6,6 +6,7 @@ Factory for and registration of model elements.
 from zope import interface
 from zope import component
 import uuid
+from gaphor.core import inject
 from gaphor.misc import odict
 from gaphor.interfaces import IService, IEventFilter
 from gaphor.UML.interfaces import IElementCreateEvent, IElementDeleteEvent, \
@@ -17,25 +18,6 @@ from gaphor.UML.element import Element
 from gaphor.UML.diagram import Diagram
 
 
-class ElementChangedEventBlocker(object):
-    """
-    Blocks all events of type IElementChangeEvent.
-
-    This filter is placed when the the element factory flushes it's content.
-    """
-    component.adapts(IElementChangeEvent)
-    interface.implements(IEventFilter)
-
-    def __init__(self, event):
-        self._event = event
-
-    def filter(self):
-        """
-        Return the event or None if the event is not to be emitted.
-        """
-        return 'Blocked by ElementFactory.flush()'
-
-
 class ElementFactory(object):
     """
     The ElementFactory is used to create elements and do lookups to
@@ -49,30 +31,15 @@ class ElementFactory(object):
     flush - model is flushed: all element are removed from the factory
             (element is None)
     """
-    interface.implements(IService)
-
     def __init__(self):
         self._elements = odict.odict()
         self._observers = list()
-        self._app = None
-
-    def init(self, app):
-        self._app = app
-        app.register_handler(self._element_deleted)
-
-    def shutdown(self):
-        # unregister after flush: the handler is needed to empty the _elements
-        self.flush()
-        if self._app:
-            self._app.unregister_handler(self._element_deleted)
 
     def create(self, type):
         """
         Create a new model element of type ``type``.
         """
         obj = self.create_as(type, str(uuid.uuid1()))
-        if self._app:
-            self._app.handle(ElementCreateEvent(self, obj))
         return obj
 
     def create_as(self, type, id):
@@ -173,69 +140,129 @@ class ElementFactory(object):
         """
         Returns True if the factory holds no elements.
         """
-        if self._elements:
-            return False
-        else:
-            return True
+        return bool(self._elements)
 
 
     def flush(self):
+        """Flush all elements (remove them from the factory). 
+        
+        Diagram elements are flushed first.  This is so that canvas updates
+        are blocked.  The remaining elements are then flushed.
         """
-        Flush all elements (remove them from the factory).
-        """
-        app = self._app
-        if app:
-            app.handle(FlushFactoryEvent(self))
-            app.register_subscription_adapter(ElementChangedEventBlocker)
+        
+        flush_element = self._flush_element
+        for element in self.lselect(lambda e: isinstance(e, Diagram)):
+            element.canvas.block_updates = True
+            flush_element(element)
+                
+        for element in self.lselect():
+            flush_element(element)
 
+    def _flush_element(self, element):
+        element.unlink()
+
+    def _unlink_element(self, element):
+        """
+        NOTE: Invoked from Element.unlink() to perform an element unlink.
+        """
         try:
-            # First flush all diagrams:
-            for value in list(self.select(lambda e: isinstance(e, Diagram))):
-                # Make sure no updates happen while destroying the canvas
-                value.canvas.block_updates = True
-                value.unlink()
-                if not app:
-                    self._element_deleted(ElementDeleteEvent(self, value))
-            for key, value in self._elements.items():
-                value.unlink()
-                if not app:
-                    self._element_deleted(ElementDeleteEvent(self, value))
-        finally:
-            if app:
-                app.unregister_subscription_adapter(ElementChangedEventBlocker)
-
-        assert len(self._elements) == 0, 'Still items in the factory: %s' % str(self._elements.values())
-
-        # Force Garbage collection, so memory allocated by items is freed.
-        import gc
-        for i in range(4): gc.collect()
-
+            del self._elements[element.id]
+        except KeyError:
+            pass
 
     def swap_element(self, element, new_class):
 	assert element in self._elements.values()
         if element.__class__ is not new_class:
             element.__class__ = new_class
 
+    def _handle(self, event):
+        """
+        Handle events coming from elements.
+        """
+        # Invoke default handler, so properties get updated.
+        component.handle(event)
+
+
+class ElementFactoryService(ElementFactory):
+    """
+    Service version of the ElementFctory.
+    """
+    interface.implements(IService)
+
+    component_registry = inject('component_registry')
+
+    def init(self, app):
+        pass
+
+    def shutdown(self):
+        self.flush()
+
+    def create(self, type):
+        """
+        Create a new model element of type ``type``.
+        """
+        obj = super(ElementFactoryService, self).create(type)
+        self.component_registry.handle(ElementCreateEvent(self, obj))
+        return obj
+
+    def flush(self):
+        """Flush all elements (remove them from the factory).  First test
+        if the element factory has a Gaphor application instance.  If yes,
+        the application will handle a FlushFactoryEvent and will register
+        a ElementChangedEventBlocker adapter.
+        
+        Diagram elements are flushed first.  This is so that canvas updates
+        are blocked.  The remaining elements are then flushed.  Finally,
+        the ElementChangedEventBlocker adapter is unregistered if the factory
+        has an application instance."""
+        
+        self.component_registry.handle(FlushFactoryEvent(self))
+        self.component_registry.register_subscription_adapter(ElementChangedEventBlocker)
+
+        try:
+            super(ElementFactoryService, self).flush()
+        finally:
+            self.component_registry.unregister_subscription_adapter(ElementChangedEventBlocker)
 
     def notify_model(self):
         """
         Send notification that a new model has been loaded by means of the
         ModelFactoryEvent event from gaphor.UML.event.
         """
-        if self._app:
-            self._app.handle(ModelFactoryEvent(self))
+        self.component_registry.handle(ModelFactoryEvent(self))
+
+    def _unlink_element(self, element):
+        """
+        NOTE: Invoked from Element.unlink() to perform an element unlink.
+        """
+        self.component_registry.handle(ElementDeleteEvent(self, element))
+        super(ElementFactoryService, self)._unlink_element(element)
+
+    def _handle(self, event):
+        """
+        Handle events coming from elements (used internally).
+        """
+        self.component_registry.handle(event)
 
 
-    @component.adapter(IElementDeleteEvent)
-    def _element_deleted(self, event):
+class ElementChangedEventBlocker(object):
+    """
+    Blocks all events of type IElementChangeEvent.
+
+    This filter is placed when the the element factory flushes it's content.
+    """
+    component.adapts(IElementChangeEvent)
+    interface.implements(IEventFilter)
+
+    def __init__(self, event):
+        self._event = event
+
+    def filter(self):
         """
-        Remove an element from the factory.
+        Returns something that evaluates to `True` so events are blocked.
         """
-        element = event.element
-        try:
-            del self._elements[element.id]
-        except KeyError:
-            pass
+        return 'Blocked by ElementFactory.flush()'
+
 
 
 # vim:sw=4:et
