@@ -27,7 +27,7 @@ methods:
 __all__ = [ 'attribute', 'enumeration', 'association', 'derivedunion', 'redefine' ]
 
 from zope import component
-from collection import collection
+from collection import collection, collectionlist
 from event import AttributeChangeEvent, AssociationSetEvent, \
                   AssociationAddEvent, AssociationDeleteEvent
 from event import DerivedChangeEvent, DerivedSetEvent, \
@@ -36,11 +36,6 @@ from event import RedefineSetEvent, RedefineAddEvent, RedefineDeleteEvent
 from interfaces import IElementChangeEvent, \
                        IAssociationChangeEvent, IAssociationSetEvent, \
                        IAssociationAddEvent, IAssociationDeleteEvent
-import operator
-import time
-
-# Stamping version time on derivedunions
-stamp = time.clock
 
 
 class umlproperty(object):
@@ -50,6 +45,9 @@ class umlproperty(object):
     The subclasses should define a ``name`` attribute that contains the name
     of the property. Derived properties (derivedunion and redefine) can be
     connected, they will be notified when the value changes.
+
+    In some cases properties call out and delegate actions to the ElementFactory,
+    for example in the case of event handling.
     """
 
     def __get__(self, obj, class_=None):
@@ -79,6 +77,12 @@ class umlproperty(object):
         """
         pass
 
+    def handle(self, event):
+        factory = event.element.factory
+        if factory:
+            factory._handle(event)
+        else:
+            component.handle(event)
 
 class attribute(umlproperty):
     """
@@ -97,12 +101,20 @@ class attribute(umlproperty):
         self.upper = upper
         
     def load(self, obj, value):
-        # FixMe: value might be a string while some other type is required:
-        #print 'attribute.load:', self.name, self.type, value,
-        if self.type is not object:
-            value = self.type(value)
-        setattr(obj, self._name, value)
-
+        
+        """Load the attribute value."""
+        
+        try:
+            
+            setattr(obj, self._name, self.type(value))
+            
+        except ValueError:
+            
+            error_msg = 'Failed to load attribute %s of type %s with value %s'\
+                        % (self._name, self.type, value)
+                        
+            raise TypeError(error_msg)
+        
     def __str__(self):
         if self.lower == self.upper:
             return '<attribute %s: %s[%s] = %s>' % (self.name, self.type, self.lower, self.default)
@@ -129,7 +141,7 @@ class attribute(umlproperty):
             delattr(obj, self._name)
         else:
             setattr(obj, self._name, value)
-        component.handle(AttributeChangeEvent(obj, self, old, value))
+        self.handle(AttributeChangeEvent(obj, self, old, value))
 
     def _del(self, obj, value=None):
         old = self._get(obj)
@@ -139,7 +151,7 @@ class attribute(umlproperty):
         except AttributeError:
             pass
         else:
-            component.handle(AttributeChangeEvent(obj, self, old, self.default))
+            self.handle(AttributeChangeEvent(obj, self, old, self.default))
 
 
 class enumeration(umlproperty):
@@ -188,7 +200,7 @@ class enumeration(umlproperty):
             delattr(obj, self._name)
         else:
             setattr(obj, self._name, value)
-        component.handle(AttributeChangeEvent(obj, self, old, value))
+        self.handle(AttributeChangeEvent(obj, self, old, value))
 
     def _del(self, obj, value=None):
         old = self._get(obj)
@@ -197,7 +209,7 @@ class enumeration(umlproperty):
         except AttributeError:
             pass
         else:
-            component.handle(AttributeChangeEvent(obj, self, old, self.default))
+            self.handle(AttributeChangeEvent(obj, self, old, self.default))
 
 
 class association(umlproperty):
@@ -258,14 +270,14 @@ class association(umlproperty):
         try:
             return getattr(obj, self._name)
         except AttributeError:
-            if self.upper > 1:
+            if self.upper == 1:
+                return None
+            else:
                 # Create the empty collection here since it might be used to
                 # add 
                 c = collection(self, obj, self.type)
                 setattr(obj, self._name, c)
                 return c
-            else:
-                return None
 
     def _set(self, obj, value, from_opposite=False, do_notify=True):
         """
@@ -295,7 +307,7 @@ class association(umlproperty):
 
             if value is None:
                 if do_notify:
-                    component.handle(event)
+                    self.handle(event)
                 return
 
             setattr(obj, self._name, value)
@@ -325,7 +337,7 @@ class association(umlproperty):
             self.stub._set(value, obj)
 
         if do_notify:
-            component.handle(event)
+            self.handle(event)
 
     def _del(self, obj, value, from_opposite=False, do_notify=True):
         """
@@ -348,7 +360,15 @@ class association(umlproperty):
                 self.stub._del(value, obj, from_opposite=True)
 
         event = None
-        if self.upper > 1:
+        if self.upper == 1:
+            try:
+                delattr(obj, self._name)
+            except:
+                pass
+            else:
+                if do_notify:
+                    event = AssociationSetEvent(obj, self, value, None)
+        else:
             c = self._get(obj)
             if c:
                 items = c.items
@@ -363,17 +383,9 @@ class association(umlproperty):
                 # Remove items collection if empty
                 if not items:
                     delattr(obj, self._name)
-        else:
-            try:
-                delattr(obj, self._name)
-            except:
-                pass
-            else:
-                if do_notify:
-                    event = AssociationSetEvent(obj, self, value, None)
 
         if do_notify and event:
-            component.handle(event)
+            self.handle(event)
 
     def unlink(self, obj):
         values = self._get(obj)
@@ -560,31 +572,31 @@ class derived(umlproperty):
                 return
                 
             # mimic the events for Set/Add/Delete
-            if self.upper > 1:
-                if IAssociationSetEvent.providedBy(event):
-                    old_value, new_value = event.old_value, event.new_value
-                    # Do a filter? Change to 
-                    component.handle(DerivedDeleteEvent(event.element, self, old_value))
-                    component.handle(DerivedAddEvent(event.element, self, new_value))
-
-                elif IAssociationAddEvent.providedBy(event):
-                    new_value = event.new_value
-                    component.handle(DerivedAddEvent(event.element, self, new_value))
-
-                elif IAssociationDeleteEvent.providedBy(event):
-                    old_value = event.old_value
-                    component.handle(DerivedDeleteEvent(event.element, self, old_value))
-
-                elif IAssociationChangeEvent.providedBy(event):
-                    component.handle(DerivedChangeEvent(event.element, self))
-                else:
-                    log.error('Don''t know how to handle event ' + str(event) + ' for derived union')
-            else:        
+            if self.upper == 1:
                 # This is a [0..1] event
                 # TODO: This is an error: [0..*] associations may be used for updating [0..1] associations
                 assert IAssociationSetEvent.providedBy(event)
                 old_value, new_value = event.old_value, event.new_value
-                component.handle(DerivedSetEvent(event.element, self, old_value, new_value))
+                self.handle(DerivedSetEvent(event.element, self, old_value, new_value))
+            else:        
+                if IAssociationSetEvent.providedBy(event):
+                    old_value, new_value = event.old_value, event.new_value
+                    # Do a filter? Change to 
+                    self.handle(DerivedDeleteEvent(event.element, self, old_value))
+                    self.handle(DerivedAddEvent(event.element, self, new_value))
+
+                elif IAssociationAddEvent.providedBy(event):
+                    new_value = event.new_value
+                    self.handle(DerivedAddEvent(event.element, self, new_value))
+
+                elif IAssociationDeleteEvent.providedBy(event):
+                    old_value = event.old_value
+                    self.handle(DerivedDeleteEvent(event.element, self, old_value))
+
+                elif IAssociationChangeEvent.providedBy(event):
+                    self.handle(DerivedChangeEvent(event.element, self))
+                else:
+                    log.error('Don''t know how to handle event ' + str(event) + ' for derived union')
 
 
 class derivedunion(derived):
@@ -614,7 +626,7 @@ class derivedunion(derived):
                     except TypeError:
                         # [0..1] property
                         u.add(tmp)
-            return u
+            return collectionlist(u)
 
     # Filter is our default filter
     filter = _union
@@ -642,35 +654,13 @@ class derivedunion(derived):
                 
             values = self._union(event.element, exclude=event.property)
 
-            if self.upper > 1:
-                if IAssociationSetEvent.providedBy(event):
-                    old_value, new_value = event.old_value, event.new_value
-                    if old_value and old_value not in values:
-                        component.handle(DerivedDeleteEvent(event.element, self, old_value))
-                    if new_value and new_value not in values:
-                        component.handle(DerivedAddEvent(event.element, self, new_value))
-
-                elif IAssociationAddEvent.providedBy(event):
-                    new_value = event.new_value
-                    if new_value not in values:
-                        component.handle(DerivedAddEvent(event.element, self, new_value))
-
-                elif IAssociationDeleteEvent.providedBy(event):
-                    old_value = event.old_value
-                    if old_value not in values:
-                        component.handle(DerivedDeleteEvent(event.element, self, old_value))
-
-                elif IAssociationChangeEvent.providedBy(event):
-                    component.handle(DerivedChangeEvent(event.element, self))
-                else:
-                    log.error('Don''t know how to handle event ' + str(event) + ' for derived union')
-            else:        
+            if self.upper == 1:
                 assert IAssociationSetEvent.providedBy(event)
                 old_value, new_value = event.old_value, event.new_value
                 # This is a [0..1] event
                 if self.single:
                     # Only one subset element, so pass the values on
-                    component.handle(DerivedSetEvent(event.element, self, old_value, new_value))
+                    self.handle(DerivedSetEvent(event.element, self, old_value, new_value))
                 else:
                     new_values = set(values)
                     if new_value:
@@ -680,7 +670,29 @@ class derivedunion(derived):
                         return
                     if values:
                         new_value = iter(values).next()
-                    component.handle(DerivedSetEvent(event.element, self, old_value, new_value))
+                    self.handle(DerivedSetEvent(event.element, self, old_value, new_value))
+            else:        
+                if IAssociationSetEvent.providedBy(event):
+                    old_value, new_value = event.old_value, event.new_value
+                    if old_value and old_value not in values:
+                        self.handle(DerivedDeleteEvent(event.element, self, old_value))
+                    if new_value and new_value not in values:
+                        self.handle(DerivedAddEvent(event.element, self, new_value))
+
+                elif IAssociationAddEvent.providedBy(event):
+                    new_value = event.new_value
+                    if new_value not in values:
+                        self.handle(DerivedAddEvent(event.element, self, new_value))
+
+                elif IAssociationDeleteEvent.providedBy(event):
+                    old_value = event.old_value
+                    if old_value not in values:
+                        self.handle(DerivedDeleteEvent(event.element, self, old_value))
+
+                elif IAssociationChangeEvent.providedBy(event):
+                    self.handle(DerivedChangeEvent(event.element, self))
+                else:
+                    log.error('Don''t know how to handle event ' + str(event) + ' for derived union')
 
 
 class redefine(umlproperty):
@@ -704,7 +716,7 @@ class redefine(umlproperty):
 
     upper = property(lambda s: s.original.upper)
     lower = property(lambda s: s.original.lower)
-
+    opposite = property(lambda s: s.original.opposite)
 
     def load(self, obj, value):
         if self.original.name == self.name:
@@ -766,11 +778,11 @@ class redefine(umlproperty):
         if event.property is self.original and isinstance(event.element, self.decl_class):
             # mimic the events for Set/Add/Delete
             if IAssociationSetEvent.providedBy(event):
-                component.handle(RedefineSetEvent(event.element, self, event.old_value, event.new_value))
+                self.handle(RedefineSetEvent(event.element, self, event.old_value, event.new_value))
             elif IAssociationAddEvent.providedBy(event):
-                component.handle(RedefineAddEvent(event.element, self, event.new_value))
+                self.handle(RedefineAddEvent(event.element, self, event.new_value))
             elif IAssociationDeleteEvent.providedBy(event):
-                component.handle(RedefineDeleteEvent(event.element, self, event.old_value))
+                self.handle(RedefineDeleteEvent(event.element, self, event.old_value))
             else:
                 log.error('Don''t know how to handle event ' + str(event) + ' for redefined association')
 
