@@ -1,13 +1,82 @@
 
 import unittest
-from zope import component
-from gaphor.application import Application
 from gaphor.UML import *
 from gaphor.UML.interfaces import *
 import gc
 import weakref, sys
 
 
+class ElementFactoryTestCase(unittest.TestCase):
+
+    def setUp(self):
+        self.factory = ElementFactory()
+
+    def tearDown(self):
+        del self.factory
+
+    def testCreate(self):
+        ef = self.factory
+
+        p = ef.create(Parameter)
+        assert len(ef.values()) == 1
+
+    def testFlush(self):
+        ef = self.factory
+
+        p = ef.create(Parameter)
+        #wp = weakref.ref(p)
+        assert len(ef.values()) == 1
+        ef.flush()
+        del p
+
+        gc.collect()
+
+        #assert wp() is None
+        assert len(ef.values()) == 0, ef.values()
+
+
+    def testWithoutApplication(self):
+        ef = ElementFactory()
+
+        p = ef.create(Parameter)
+        assert ef.size() == 1, ef.size()
+
+        ef.flush()
+        assert ef.size() == 0, ef.size()
+
+        p = ef.create(Parameter)
+        assert ef.size() == 1, ef.size()
+
+        p.unlink()
+        assert ef.size() == 0, ef.size()
+
+
+    def testUnlink(self):
+        ef = self.factory
+        p = ef.create(Parameter)
+
+        assert len(ef.values()) == 1
+
+        p.unlink()
+
+        assert len(ef.values()) == 0, ef.values()
+
+        p = ef.create(Parameter)
+        p.defaultValue = 'l'
+
+        assert len(ef.values()) == 1
+
+        p.unlink()
+        del p
+
+        assert len(ef.values()) == 0, ef.values()
+
+
+
+
+from zope import component
+from gaphor.application import Application
+
 # Event handlers are registered as persisting top level handlers, since no
 # unsubscribe functionality is provided.
 handled = False
@@ -24,17 +93,16 @@ def handler(event):
 component.provideHandler(handler)
 
 
-class ElementFactoryTestCase(unittest.TestCase):
+class ElementFactoryServiceTestCase(unittest.TestCase):
 
     def setUp(self):
-        Application.init_components()
-        self.factory = ElementFactory()
-        self.factory.init(Application)
+        Application.init(['element_factory'])
+        self.factory = Application.get_service('element_factory')
 
     def tearDown(self):
-        self.factory.shutdown()
         del self.factory
         self.clearEvents()
+        Application.shutdown()
 
     def clearEvents(self):
         global handled, events, last_event
@@ -42,66 +110,6 @@ class ElementFactoryTestCase(unittest.TestCase):
         events = [ ]
         last_event = None
 
-    def testCreate(self):
-        ef = self.factory
-
-        p = ef.create(Parameter)
-        assert len(ef.values()) == 1
-
-    def testFlush(self):
-        ef = self.factory
-
-        p = ef.create(Parameter)
-        wp = weakref.ref(p)
-        assert len(ef.values()) == 1
-        ef.flush()
-        del p
-        self.clearEvents()
-
-        gc.collect()
-
-        assert wp() is None
-        assert len(ef.values()) == 0
-
-
-    def testWithoutApplication(self):
-        ef = ElementFactory()
-
-        p = ef.create(Parameter)
-        assert ef.size() == 1, ef.size()
-
-        ef.flush()
-        assert ef.size() == 0, ef.size()
-
-        p = ef.create(Parameter)
-        assert ef.size() == 1, ef.size()
-
-        p.unlink()
-        # TODO: does not work
-        assert ef.size() == 1, ef.size()
-
-
-    def testUnlink(self):
-        ef = self.factory
-        p = ef.create(Parameter)
-
-        assert len(ef.values()) == 1
-
-        p.unlink()
-
-        assert len(ef.values()) == 0
-
-        p = ef.create(Parameter)
-        l = ef.create(LiteralString)
-        p.defaultValue = l
-
-        assert len(ef.values()) == 2
-
-        p.unlink()
-        del p
-
-        assert len(ef.values()) == 0, ef.values()
-
     def testCreateEvent(self):
         ef = self.factory
         global handled
