@@ -14,12 +14,10 @@ factory = ElementFactory()
 class AttributeTestCase(unittest.TestCase):
 
     def setUp(self):
-        factory.init(Application)
-        factory.flush()
-
+        pass
 
     def tearDown(self):
-        factory.shutdown()
+        factory.flush()
 
 
     def test_simple_format(self):
@@ -29,7 +27,6 @@ class AttributeTestCase(unittest.TestCase):
         a.name = 'myattr'
         self.assertEquals('+ myattr', format(a))
 
-        a.typeValue = factory.create(UML.LiteralSpecification)
-        a.typeValue.value = 'int'
+        a.typeValue = 'int'
         self.assertEquals('+ myattr: int', format(a))
 
