@@ -28,8 +28,8 @@ TODO:
 
 import gobject
 import gtk
+import math
 from gaphor.core import _, inject, transactional
-from gaphor.application import Application
 from gaphor.services.elementdispatcher import EventWatcher
 from gaphor.ui.interfaces import IPropertyPage
 from gaphor.diagram import items
@@ -234,7 +234,7 @@ class ClassOperations(EditableTreeModel):
 
     def _get_rows(self):
         for operation in self._item.subject.ownedOperation:
-            yield [UML.format(operation), operation.isStatic, operation]
+            yield [UML.format(operation), operation.isAbstract, operation.isStatic, operation]
 
 
     def _create_object(self):
@@ -250,11 +250,15 @@ class ClassOperations(EditableTreeModel):
             UML.parse(operation, value)
             row[0] = UML.format(operation)
         elif col == 1:
-            operation.isStatic = not operation.isStatic
-            row[1] = operation.isStatic
+            operation.isAbstract = not operation.isAbstract
+            row[1] = operation.isAbstract
         elif col == 2:
+            operation.isStatic = not operation.isStatic
+            row[2] = operation.isStatic
+        elif col == 3:
             row[0] = UML.format(operation)
-            row[1] = operation.isStatic
+            row[1] = operation.isAbstract
+            row[2] = operation.isStatic
 
 
     def _swap_objects(self, o1, o2):
@@ -765,10 +769,10 @@ Add and edit class attributes according to UML syntax. Attribute syntax examples
             .watch('ownedAttribute.isDerived', handler) \
             .watch('ownedAttribute.visibility', handler) \
             .watch('ownedAttribute.isStatic', handler) \
-            .watch('ownedAttribute.lowerValue<LiteralSpecification>.value', handler) \
-            .watch('ownedAttribute.upperValue<LiteralSpecification>.value', handler) \
-            .watch('ownedAttribute.defaultValue<LiteralSpecification>.value', handler) \
-            .watch('ownedAttribute.typeValue<LiteralSpecification>.value', handler) \
+            .watch('ownedAttribute.lowerValue', handler) \
+            .watch('ownedAttribute.upperValue', handler) \
+            .watch('ownedAttribute.defaultValue', handler) \
+            .watch('ownedAttribute.typeValue', handler) \
             .register_handlers()
         tree_view.connect('destroy', self.watcher.unregister_handlers)
         return page
@@ -815,7 +819,7 @@ class OperationsPage(object):
         page.pack_start(hbox, expand=False)
 
         def create_model():
-            return ClassOperations(self.item, (str, bool, object))
+            return ClassOperations(self.item, (str, bool, bool, object))
 
         self.model = create_model()
         tip = """\
@@ -824,7 +828,7 @@ Add and edit class operations according to UML syntax. Operation syntax examples
 - + call(a: int, b: str)
 - # call(a: int: b: str): bool
 """
-        tree_view = create_tree_view(self.model, (_('Operation'), _('S')), tip)
+        tree_view = create_tree_view(self.model, (_('Operation'), _('A'), _('S')), tip)
         page.pack_start(tree_view)
 
         @async(single=True)
@@ -836,13 +840,13 @@ Add and edit class operations according to UML syntax. Operation syntax examples
         self.watcher.watch('ownedOperation.name', handler) \
             .watch('ownedOperation.isAbstract', handler) \
             .watch('ownedOperation.visibility', handler) \
-            .watch('ownedOperation.returnResult.lowerValue<LiteralSpecification>.value', handler) \
-            .watch('ownedOperation.returnResult.upperValue<LiteralSpecification>.value', handler) \
-            .watch('ownedOperation.returnResult.typeValue<LiteralSpecification>.value', handler) \
-            .watch('ownedOperation.formalParameter.lowerValue<LiteralSpecification>.value', handler) \
-            .watch('ownedOperation.formalParameter.upperValue<LiteralSpecification>.value', handler) \
-            .watch('ownedOperation.formalParameter.typeValue<LiteralSpecification>.value', handler) \
-            .watch('ownedOperation.formalParameter.defaultValue<LiteralSpecification>.value', handler) \
+            .watch('ownedOperation.returnResult.lowerValue', handler) \
+            .watch('ownedOperation.returnResult.upperValue', handler) \
+            .watch('ownedOperation.returnResult.typeValue', handler) \
+            .watch('ownedOperation.formalParameter.lowerValue', handler) \
+            .watch('ownedOperation.formalParameter.upperValue', handler) \
+            .watch('ownedOperation.formalParameter.typeValue', handler) \
+            .watch('ownedOperation.formalParameter.defaultValue', handler) \
             .register_handlers()
         tree_view.connect('destroy', self.watcher.unregister_handlers)
 
@@ -920,7 +924,7 @@ class DependencyPropertyPage(object):
         combo = self.combo
         item = self.item
         index = combo.get_model().get_index(item.dependency_type)
-        combo.props.sensitive = not item.auto_dependency and item.subject is None
+        combo.props.sensitive = not item.auto_dependency
         combo.set_active(index)
 
 
@@ -929,6 +933,9 @@ class DependencyPropertyPage(object):
         combo = self.combo
         cls = combo.get_model().get_value(combo.get_active())
         self.item.dependency_type = cls
+        if self.item.subject:
+            self.element_factory.swap_element(self.item.subject, cls)
+            self.item.request_update()
 
 
     @transactional
@@ -1051,7 +1058,7 @@ class AssociationPropertyPage(NamedItemPropertyPage):
                     expander.show_all()
                     vbox.pack_start(expander, expand=False)
             except Exception, e:
-                log.error('Could not construct property page for ' + name, e)
+                log.error('Could not construct property page for ' + name, exc_info=True)
 
 component.provideAdapter(AssociationPropertyPage, name='Properties')
 
@@ -1076,21 +1083,25 @@ class AssociationEndPropertyPage(object):
         vbox = gtk.VBox()
 
         entry = gtk.Entry()
-        entry.set_text(UML.umlfmt.format_attribute(self.subject, multiplicity=True) or '')
+        #entry.set_text(UML.format(self.subject, visibility=True, is_derived=Truemultiplicity=True) or '')
 
         # monitor subject attribute (all, cause it contains many children)
         changed_id = entry.connect('changed', self._on_end_name_change)
         def handler(event):
             if not entry.props.has_focus:
                 entry.handler_block(changed_id)
-                entry.set_text(UML.umlfmt.format_attribute(self.subject, multiplicity=True) or '')
+                entry.set_text(UML.format(self.subject,
+                                          visibility=True, is_derived=True,
+                                          multiplicity=True) or '')
                 #entry.set_text(UML.format(self.subject, multiplicity=True) or '')
                 entry.handler_unblock(changed_id)
+        handler(None)
+
         self.watcher.watch('name', handler) \
                     .watch('aggregation', handler)\
                     .watch('visibility', handler)\
-                    .watch('lowerValue<LiteralSpecification>.value', handler)\
-                    .watch('upperValue<LiteralSpecification>.value', handler)\
+                    .watch('lowerValue', handler)\
+                    .watch('upperValue', handler)\
                     .register_handlers()
         entry.connect("destroy", self.watcher.unregister_handlers)
 
@@ -1099,21 +1110,12 @@ class AssociationEndPropertyPage(object):
         entry.set_tooltip_text("""\
 Enter attribute name and multiplicity, for example
 - name
-- name [1]
++ name [1]
 - name [1..2]
-- 1..2
+~ 1..2
 - [1..2]\
 """)
 
-        combo = gtk.combo_box_new_text()
-        for t in ('public (+)', 'protected (#)', 'package (~)', 'private (-)'):
-            combo.append_text(t)
-        
-        combo.set_active(['public', 'protected', 'package', 'private'].index(self.subject.visibility))
-
-        combo.connect('changed', self._on_visibility_change)
-        vbox.pack_start(combo, expand=False)
-
         combo = gtk.combo_box_new_text()
         for t in ('Unknown navigation', 'Not navigable', 'Navigable'):
             combo.append_text(t)
@@ -1139,10 +1141,6 @@ Enter attribute name and multiplicity, for example
     def _on_end_name_change(self, entry):
         UML.parse(self.subject, entry.get_text())
 
-    @transactional
-    def _on_visibility_change(self, combo):
-        self.subject.visibility = ('public', 'protected', 'package', 'private')[combo.get_active()]
-
     @transactional
     def _on_navigability_change(self, combo):
         nav = self.NAVIGABILITY[combo.get_active()]
@@ -1233,7 +1231,7 @@ class ObjectNodePropertyPage(NamedItemPropertyPage):
 
         hbox = create_hbox_label(self, page, _('Upper bound'))
         entry = gtk.Entry()        
-        entry.set_text(subject.upperBound and subject.upperBound.value or '')
+        entry.set_text(subject.upperBound or '')
         entry.connect('changed', self._on_upper_bound_change)
         hbox.pack_start(entry)
 
@@ -1296,10 +1294,15 @@ class JoinNodePropertyPage(NamedItemPropertyPage):
         if isinstance(subject, UML.JoinNode):
             hbox = create_hbox_label(self, page, _('Join specification'))
             entry = gtk.Entry()        
-            entry.set_text(subject.joinSpec and subject.joinSpec.value or '')
+            entry.set_text(subject.joinSpec or '')
             entry.connect('changed', self._on_join_spec_change)
             hbox.pack_start(entry)
 
+        button = gtk.CheckButton(_('Horizontal'))
+        button.set_active(self.item.matrix[2] != 0)
+        button.connect('toggled', self._on_horizontal_change)
+        page.pack_start(button, expand=False)
+
         return page
 
     def update(self):
@@ -1308,8 +1311,15 @@ class JoinNodePropertyPage(NamedItemPropertyPage):
     @transactional
     def _on_join_spec_change(self, entry):
         value = entry.get_text().strip()
-        self.item.set_join_spec(value)
+        print 'new joinspec', value
+        self.subject.joinSpec = value
 
+    def _on_horizontal_change(self, button):
+        if button.get_active():
+            self.item.matrix.rotate(math.pi/2)
+        else:
+            self.item.matrix.rotate(-math.pi/2)
+        self.item.request_update()
 
 component.provideAdapter(JoinNodePropertyPage, name='Properties')
 
@@ -1328,7 +1338,7 @@ class FlowPropertyPageAbstract(NamedElementPropertyPage):
 
         hbox = create_hbox_label(self, page, _('Guard'))
         entry = gtk.Entry()        
-        entry.set_text(subject.guard and subject.guard.value or '')
+        entry.set_text(subject.guard or '')
         changed_id = entry.connect('changed', self._on_guard_change)
         hbox.pack_start(entry)
 
@@ -1338,7 +1348,7 @@ class FlowPropertyPageAbstract(NamedElementPropertyPage):
             entry.set_text(v if v else '')
             entry.handler_unblock(changed_id)
 
-        self.watcher.watch('guard<LiteralSpecification>.value', handler).register_handlers()
+        self.watcher.watch('guard', handler).register_handlers()
         entry.connect('destroy', self.watcher.unregister_handlers)
 
         return page
@@ -1346,7 +1356,7 @@ class FlowPropertyPageAbstract(NamedElementPropertyPage):
     @transactional
     def _on_guard_change(self, entry):
         value = entry.get_text().strip()
-        self.subject.guard.value = value
+        self.subject.guard = value
 
 
 # fixme: unify ObjectFlowPropertyPage and ControlFlowPropertyPage
