@@ -4,21 +4,17 @@ The diagram package contains items (to be drawn on the diagram), tools
 diagram).
 """
 
-__version__ = '$revision$'
-__author__ = 'Arjan J. Molenaar'
-__date__ = '$date$'
-
 import inspect
 import gobject
+import uuid
 
-from gaphor.misc import uniqueid
 from gaphor.diagram.style import Style
 
 # Map UML elements to their (default) representation.
 _uml_to_item_map = { }
 
 def create(type):
-    return create_as(type, uniqueid.generate_id())
+    return create_as(type, str(uuid.uuid1()))
 
 def create_as(type, id):
     return type(id)
@@ -32,6 +28,27 @@ def set_diagram_item(element, item):
     _uml_to_item_map[element] = item
 
 
+def uml(uml_class, stereotype=None):
+    """
+    Assign UML metamodel class and a stereotype to diagram item.
+
+    :Parameters:
+     uml_class
+        UML metamodel class.
+     stereotype
+        Stereotype name (i.e. 'subsystem').
+    """
+    def f(item_class):
+        t = uml_class
+        if stereotype is not None:
+            t = (uml_class, stereotype)
+            item_class.__stereotype__ = stereotype
+        set_diagram_item(t, item_class)
+        return item_class
+    return f
+
+
+
 class DiagramItemMeta(type):
     """
     Initialize a new diagram item.
