@@ -4,41 +4,42 @@ Actor item classes.
 
 from math import pi
 
-from gaphas.util import text_align, text_set_font
-
 from gaphor import UML
-#from gaphor.diagram.align import V_ALIGN_BOTTOM
+from gaphor.diagram.style import ALIGN_CENTER, ALIGN_BOTTOM
 from gaphor.diagram.classifier import ClassifierItem
-import font
 
 class ActorItem(ClassifierItem):
-    """Actor item is a classifier in icon mode.
+    """
+    Actor item is a classifier in icon mode.
 
-    In future maybe it will be possible to switch to comparment mode.
+    Maybe it should be possible to switch to comparment mode in the future.
     """
 
     __uml__ = UML.Actor
-#    __o_align__  = True
-#    __s_valign__ = V_ALIGN_BOTTOM
 
     HEAD = 11
     ARM  = 19
     NECK = 10
     BODY = 20
+    __style__ = {
+        'min-size': (ARM * 2, HEAD + NECK + BODY + ARM),
+        'name-align': (ALIGN_CENTER, ALIGN_BOTTOM),
+        'name-padding': (5, 0, 5, 0),
+        'name-outside': True,
+    }
 
     def __init__(self, id = None):
         ClassifierItem.__init__(self, id)
 
         self.drawing_style = self.DRAW_ICON
 
-        self.min_height = self.HEAD + self.NECK + self.BODY + self.ARM
-        self.min_width = self.ARM * 2
-        self.height = self.min_height
-        self.width = self.min_width
 
     def draw_icon(self, context):
-        """Actors use Icon style.
         """
+        Draw actor's icon creature.
+        """
+        super(ActorItem, self).draw(context)
+
         cr = context.cairo
 
         head, neck, arm, body = self.HEAD, self.NECK, self.ARM, self.BODY
@@ -64,12 +65,5 @@ class ActorItem(ClassifierItem):
         cr.line_to(arm * 2 * fx, (head + neck + body + arm) * fy)
         cr.stroke()
 
-        # The item's boundings are not related to the size of the actors name
-        # So the update is trivial:
-        text = self.subject.name
-        if text:
-            text_set_font(cr, font.FONT_NAME)
-            text_align(cr, self.width/2.0, self.height + 10, text, align_y=0)
-
 
 # vim:sw=4:et
