@@ -13,16 +13,6 @@ class ImplementationItem(DiagramLine):
         DiagramLine.__init__(self, id)
         self._solid = False 
 
-    def post_update(self, context):
-        # change look into solid line when connected to folded interface
-        from interface import InterfaceItem
-        conn_to = self.head.connected_to
-        if isinstance(conn_to, InterfaceItem) \
-           and conn_to.is_folded():
-            self._solid = True
-        else:
-            self._solid = False
-        DiagramLine.post_update(self, context)
 
     def draw_head(self, context):
         cr = context.cairo
@@ -35,10 +25,12 @@ class ImplementationItem(DiagramLine):
             cr.stroke()
             cr.move_to(15, 0)
 
+
     def draw(self, context):
         if not self._solid:
             context.cairo.set_dash((7.0, 5.0), 0)
         super(ImplementationItem, self).draw(context)
 
 
+
 # vim:sw=4
