@@ -2,13 +2,13 @@
 Diagram item with compartments.
 """
 
-import cairo
+import cairo, pango, pangocairo
 from gaphas.state import observed, reversible_property
 
 from gaphor import UML
 from gaphor.diagram.diagramitem import DiagramItem
 from gaphor.diagram.nameditem import NamedItem
-from gaphas.util import text_extents, text_set_font, text_align, text_underline
+from textelement import text_extents, text_align
 
 
 class FeatureItem(object):
@@ -77,13 +77,18 @@ class FeatureItem(object):
 
     def draw(self, context):
         cr = context.cairo
-        if self.font:
-            text_set_font(cr, self.font)
-        if hasattr(self.subject, 'isStatic') and self.subject.isStatic:
-            text_underline(cr, 0, 0, self.render() or '')
-        else:
-            text_align(cr, 0, 0, self.render(), align_x=1, align_y=1)
-
+        if isinstance(cr, cairo.Context):
+            cr = pangocairo.CairoContext(cr)
+            layout = cr.create_layout()
+            layout.set_font_description(pango.FontDescription(self.font))
+            layout.set_text(self.render() or '')
+        
+            if hasattr(self.subject, 'isStatic') and self.subject.isStatic:
+                attrlist = pango.AttrList()
+                attrlist.insert(pango.AttrUnderline(pango.UNDERLINE_SINGLE,
+                                2, -1))
+                layout.set_attributes(attrlist)
+            cr.show_layout(layout)
 
 
 class Compartment(list):
@@ -102,6 +107,7 @@ class Compartment(list):
         self.width = 0
         self.height = 0
         self.title = None
+        self.font = None
         self.title_height = 0
         self.use_extra_space = False
 
@@ -167,6 +173,8 @@ class Compartment(list):
         cr.translate(padding[1], padding[0])
         offset = 0
         if self.title:
+            text_align(cr, self.owner.width / 2.0, padding[0],
+                self.title, font=self.font, align_y=1)
             offset += self.title_height + vspacing
         for item in self:
             cr.save()
@@ -235,7 +243,7 @@ class CompartmentItem(NamedItem):
         'feature-font': 'sans 10',
         'from-padding': (7, 2, 7, 2),
         'compartment-padding': (5, 5, 5, 5), # (top, right, bottom, left)
-        'compartment-vspacing': 3,
+        'compartment-vspacing': 0,
         'name-padding': (10, 10, 10, 10),
         'stereotype-padding': (10, 10, 2, 10),
         # extra space can be used by header or a compartment;
@@ -528,9 +536,6 @@ class CompartmentItem(NamedItem):
             cr.line_to(self.width, 0)
             cr.stroke()
 
-            if comp.title:
-                padding = self.style.compartment_padding
-                text_align(cr, self.width / 2.0, padding[0], comp.title, align_y=1)
             try:
                 comp.draw(context)
             finally:
@@ -577,4 +582,4 @@ class CompartmentItem(NamedItem):
         return None
 
 
-# vim:sw=4:et
+# vi:ai:sw=4:et
