@@ -10,13 +10,14 @@ class ComponentItem(ClassifierItem):
     __uml__  = UML.Component
     __icon__ = True
 
+    __style__ = {
+            'name-padding': (10, 25, 10, 10),
+    }
+
     BAR_WIDTH     = 10
     BAR_HEIGHT    =  5
     BAR_PADDING   =  5
 
-    popup_menu = ClassifierItem.popup_menu \
-        + ('separator', 'IndirectlyInstantiated')
-
     def __init__(self, id=None):
         ClassifierItem.__init__(self, id)
         # Set drawing style to compartment w// small icon
@@ -25,6 +26,8 @@ class ComponentItem(ClassifierItem):
     def draw_compartment_icon(self, context):
         cr = context.cairo
         cr.save()
+        self.draw_compartment(context)
+        cr.restore()
 
         ix, iy = self.get_icon_pos()
 
@@ -49,8 +52,6 @@ class ComponentItem(ClassifierItem):
         cr.set_source(color)
         cr.stroke()
 
-        cr.restore()
-        self.draw_compartment(context)
 
 
 # vim:sw=4:et
