@@ -100,12 +100,15 @@ Therefore, code of connector items is written with assumption, that
 interfaces are connectable elements.
 """
 
+from logging import getLogger
 from gaphor import UML
 from gaphor.diagram.diagramline import NamedLine
 from gaphor.diagram.style import ALIGN_CENTER, ALIGN_BOTTOM
 
 from operator import attrgetter
 
+logger = getLogger('Connector')
+
 class ConnectorItem(NamedLine):
     """
     Connector item line.
@@ -149,7 +152,7 @@ class ConnectorItem(NamedLine):
         try:
             self._interface.text = self.subject.end['it.role', 0].role.name
         except (IndexError, AttributeError), e:
-            log.debug(e)
+            logger.error(e)
             self._interface.text = ''
         else:
             self.request_update(matrix=False)
