@@ -3,10 +3,9 @@ Abstract classes for element-like Diagram items.
 """
 
 import gobject
+import cairo
 import gaphas
 from zope import component
-from gaphor.application import Application
-#from gaphor.UML.event import ElementDeleteEvent
 from diagramitem import DiagramItem
 from gaphor.diagram.style import get_text_point
 
@@ -15,6 +14,10 @@ class ElementItem(gaphas.Element, DiagramItem):
     __style__ = {
         'min-size': (0, 0),
         'stereotype-padding': (5, 10, 5, 10),
+	'background': 'solid',
+	'background-color': (1, 1, 1, 0.8),
+	'highlight-color': (0, 0, 1, 0.4),
+	'background-gradient': ((0.8, 0.8, 0.8, 0.5), (1.0, 1.0, 1.0, 0.5))
     }
 
     def __init__(self, id=None):
@@ -50,26 +53,6 @@ class ElementItem(gaphas.Element, DiagramItem):
         self.unregister_handlers()
 
 
-#    def register_handlers(self):
-#	super(ElementItem, self).register_handlers()
-#	Application.register_handler(self._on_element_delete)
-
-
-#    def unregister_handlers(self):
-#	super(ElementItem, self).unregister_handlers()
-#	Application.unregister_handler(self._on_element_delete)
-
-
-## TODO: Not working anymore. subject is already cleared
-#    @component.adapter(ElementDeleteEvent)
-#    def _on_element_delete(self, event):
-#	"""
-#	Delete the item if the subject is deleted.
-#	"""
-#	if event and event.element is self.subject:
-#	    self.unlink()
-
-
     def pre_update(self, context):
         #super(ElementItem, self).pre_update(context)
         self.update_stereotype()
@@ -88,15 +71,38 @@ class ElementItem(gaphas.Element, DiagramItem):
         DiagramItem.post_update(self, context)
 
 
+    def fill_background(self, context):
+	cr = context.cairo
+	cr.save()
+	try:
+	    if self.style.background == 'solid':
+		cr.set_source_rgba(*self.style.background_color)
+		cr.fill_preserve()
+		
+	    elif self.style.background == 'gradient':
+		# TODO: check if style is gradient
+		g = cairo.LinearGradient(0, 0, self.width, self.height)
+		for i, c in enumerate(self.style.background_gradient):
+		    g.add_color_stop_rgba(i, *c)
+		cr.set_source(g)
+		cr.fill_preserve()
+	finally:
+	    cr.restore()
+
+    def highlight(self, context):
+	cr = context.cairo
+	cr.save()
+	try:
+	    if context.dropzone:
+		cr.set_source_rgba(*self.style.highlight_color)
+		cr.set_line_width(cr.get_line_width() * 3.141)
+		cr.stroke_preserve()
+	finally:
+	    cr.restore()
+
     def draw(self, context):
-        if context.dropzone:
-            cr = context.cairo
-            cr.save()
-            cr.set_source_rgba(0.0, 1.0, 0.0, 0.05)
-            cr.rectangle(0, 0, self.width, self.height)
-            cr.fill_preserve()
-            cr.stroke()
-            cr.restore()
+	self.fill_background(context)
+        self.highlight(context)
         gaphas.Element.draw(self, context)
         DiagramItem.draw(self, context)
 
@@ -108,4 +114,4 @@ class ElementItem(gaphas.Element, DiagramItem):
         return x, y
 
 
-# vim:sw=4
+# vim:sw=4:et:ai
