@@ -39,7 +39,7 @@ from gaphor.diagram.activitynodes import FlowFinalNodeItem
 from gaphor.diagram.activitynodes import DecisionNodeItem
 from gaphor.diagram.activitynodes import ForkNodeItem
 from gaphor.diagram.objectnode import ObjectNodeItem
-from gaphor.diagram.actions.action import ActionItem
+from gaphor.diagram.actions.action import ActionItem, SendSignalActionItem, AcceptEventActionItem
 from gaphor.diagram.actions.flow import FlowItem
 from gaphor.diagram.actions.partition import PartitionItem
 
