@@ -40,9 +40,11 @@ class Line(_Line):
         elif name == 'points':
             points = eval(value)
             for x in xrange(len(points) - 2):
-                self.split_segment(0)
+                h = self._create_handle((0, 0))
+                self._handles.insert(1, h)
             for i, p in enumerate(points):
                 self.handles()[i].pos = p
+            self._update_ports()
         elif name == 'horizontal':
             self.horizontal = eval(value)
         elif name == 'orthogonal':
@@ -102,7 +104,7 @@ class Box(Element):
         cr = context.cairo
         nw = self._handles[NW]
         style = self.style
-        cr.rectangle(nw.x, nw.y, self.width, self.height)
+        cr.rectangle(nw.pos.x, nw.pos.y, self.width, self.height)
         cr.set_source_rgba(*style.fill_color)
         cr.fill_preserve()
         cr.set_source_rgba(*style.border_color)
