@@ -5,12 +5,12 @@ item, guard of flow item, etc.
 
 import math
 
+import cairo, pango, pangocairo
 from gaphor.diagram.style import Style
 from gaphor.diagram.style import ALIGN_CENTER, ALIGN_TOP
 
 from gaphas.geometry import distance_rectangle_point, Rectangle
-from gaphas.util import text_extents, text_align, text_multiline, \
-    text_set_font
+
 
 DEFAULT_TEXT_FONT = 'sans 10'
 
@@ -25,6 +25,72 @@ def swap(list, el1, el2):
     list[i2] = el1
 
 
+def _text_layout(cr, text, font, width):
+    cr = pangocairo.CairoContext(cr)
+    layout = cr.create_layout()
+    if font:
+        layout.set_font_description(pango.FontDescription(font))
+    layout.set_text(text)
+    layout.set_width(int(width * pango.SCALE))
+    #layout.set_height(height)
+    return layout
+
+
+def text_extents(cr, text, font=None, width=-1, height=-1):
+    if not text:
+        return 0, 0
+    layout = _text_layout(cr, text, font, width)
+    return layout.get_pixel_size()
+
+
+def text_align(cr, x, y, text, font, width=-1, height=-1,
+               align_x=0, align_y=0, padding_x=0, padding_y=0):
+    """
+    Draw text relative to (x, y).
+    x, y - coordinates
+    text - text to print (utf8)
+    font - The font to render in
+    width
+    height
+    align_x - 1 (top), 0 (middle), -1 (bottom)
+    align_y - 1 (left), 0 (center), -1 (right)
+    padding_x - padding (extra offset), always > 0
+    padding_y - padding (extra offset), always > 0
+    """
+    if not isinstance(cr, cairo.Context):
+        return
+    if not text:
+        return
+
+    layout = _text_layout(cr, text, font, width)
+
+    w, h = layout.get_pixel_size()
+
+    if align_x == 0:
+        x = 0.5 - (w / 2) + x
+    elif align_x < 0:
+        x = -w + x - padding_x
+    else:
+        x = x + padding_x
+    if align_y == 0:
+        y = 0.5 - (h / 2) + y
+    elif align_y < 0:
+        y = -h + y - padding_y
+    else:
+        y = y + padding_y
+    cr.move_to(x, y)
+    cr.update_layout(layout)
+    cr.show_layout(layout)
+
+
+def text_center(cr, x, y, text, font):
+    text_align(cr, x, y, text, font=font, align_x=0, align_y=0)
+
+
+def text_multiline(cr, x, y, text, font, width=-1, height=-1):
+    text_align(cr, x, y, text, font=font, width=width, height=height, align_x=1, align_y=1)
+
+
 class EditableTextSupport(object):
     """
     Editable text support to allow display and edit text parts of a diagram
@@ -139,7 +205,7 @@ class EditableTextSupport(object):
         """
         cr = context.cairo
         for txt in texts:
-            w, h = text_extents(cr, txt.text, font=txt.style.font, multiline=True)
+            w, h = text_extents(cr, txt.text, font=txt.style.font)
             txt.bounds.width = max(15, w)
             txt.bounds.height = max(10, h)
 
@@ -385,9 +451,13 @@ class TextElement(object):
         width, height = bounds.width, bounds.height
 
         cr = context.cairo
-        text_set_font(cr, self._style.font)
-        text_multiline(cr, x, y, self.text)
-        cr.stroke()
+        if isinstance(cr, cairo.Context) and self.text:
+            cr = pangocairo.CairoContext(context.cairo)
+            cr.move_to(x, y)
+            layout = cr.create_layout()
+            layout.set_font_description(pango.FontDescription(self._style.font))
+            layout.set_text(self.text)
+            cr.show_layout(layout)
         if self.editable and (context.hovered or context.focused):
             cr.save()
             cr.set_source_rgb(0.6, 0.6, 0.6)
