@@ -135,14 +135,14 @@ class GTKInterpreterConsole(gtk.ScrolledWindow):
 
     __gtype_name__ = 'GTKInterpreterConsole'
 
-    def __init__(self):
+    def __init__(self, locals=None):
         gtk.ScrolledWindow.__init__(self)
         self.set_policy (gtk.POLICY_AUTOMATIC,gtk.POLICY_AUTOMATIC)
 
         self.text = gtk.TextView()
         self.text.set_wrap_mode(True)
 
-        self.interpreter = code.InteractiveInterpreter()
+        self.interpreter = code.InteractiveInterpreter(locals)
 
         self.completer = Completer(self.interpreter.locals)
         self.buffer = []
