@@ -10,7 +10,7 @@ from gaphor.tests.testcase import TestCase
 
 class DiagramLayoutTestCase(TestCase):
 
-    services = TestCase.services + ['gui_manager', 'properties', 'action_manager', 'diagram_layout']
+    services = TestCase.services + ['main_window', 'ui_manager', 'properties', 'action_manager', 'diagram_layout']
 
 
     def testDiagramLayout(self):
