@@ -23,7 +23,7 @@ class PyNSource(object):
 
     interface.implements(IService, IActionProvider)
 
-    gui_manager = inject('gui_manager')
+    main_window = inject('main_window')
 
     menu_xml = """
       <ui>
@@ -72,14 +72,14 @@ class PyNSource(object):
         engineer = Engineer()
         engineer.process(files)
 
-        main_window = self.gui_manager.main_window
+        main_window = self.main_window
         # Open and select the new diagram in the main window:
         main_window.select_element(engineer.diagram)
         main_window.show_diagram(engineer.diagram)
 
     def create_dialog(self):
         dialog = gtk.Dialog("Import Python files",
-                            self.gui_manager.main_window.window,
+                            self.main_window.window,
                             gtk.DIALOG_MODAL,
                             (gtk.STOCK_OK, gtk.RESPONSE_OK,
                              gtk.STOCK_CANCEL, gtk.RESPONSE_CANCEL))
@@ -212,16 +212,23 @@ class PyNSource(object):
             iter = view.get_iter('0')
         except ValueError:
             pass
-        self.execute_button.set_property('sensitive', bool(iter))
+        #self.execute_button.set_property('sensitive', bool(iter))
 
     def on_add_dir_clicked(self, button):
         import os
-        filesel = gtk.FileSelection('Add Source Code')
-        filesel.hide_fileop_buttons()
+        
+        filesel = gtk.FileChooserDialog(title='Add Source Code',
+                                        action=gtk.FILE_CHOOSER_ACTION_OPEN,
+                                        buttons=(gtk.STOCK_CANCEL,
+                                                 gtk.RESPONSE_CANCEL,
+                                                 gtk.STOCK_OPEN,
+                                                 gtk.RESPONSE_OK))
+
         filesel.set_select_multiple(True)
         filesel.set_filename('~/')
+
         response = filesel.run()
-        selection = filesel.get_selections()
+        selection = filesel.get_filenames()        
         filesel.destroy()
 
         if response == gtk.RESPONSE_OK:
