@@ -6,6 +6,7 @@ import gtk
 from zope import interface, component
 from gaphor.core import _, inject, action, build_action_group
 from gaphor.interfaces import IService, IActionProvider
+from gaphor.ui.filedialog import FileDialog
 
 import exportmodel
 
@@ -14,7 +15,7 @@ class XMIExport(object):
     interface.implements(IService, IActionProvider)
 
     element_factory = inject('element_factory')
-    gui_manager = inject('gui_manager')
+    main_window = inject('main_window')
 
     menu_xml = """
       <ui>
@@ -39,28 +40,25 @@ class XMIExport(object):
     @action(name='file-export-xmi', label=_('Export to XMI'),
             tooltip=_('Export model to XMI (XML Model Interchange) format'))
     def execute(self):
-        filename = self.gui_manager.main_window.get_filename()
+        filename = self.main_window.get_filename()
         if filename:
             filename = filename.replace('.gaphor', '.xmi')
         else:
             filename = 'model.xmi'
 
-        filesel = gtk.FileChooserDialog(title='Export model to XMI file',
-                                        action=gtk.FILE_CHOOSER_ACTION_SAVE,
-                                        buttons=(gtk.STOCK_CANCEL,gtk.RESPONSE_CANCEL,gtk.STOCK_SAVE,gtk.RESPONSE_OK))
-        filesel.set_current_name(filename)
-
-        response = filesel.run()
-        filename = filesel.get_filename()
-        filesel.destroy()
-        if response == gtk.RESPONSE_OK:
-            if filename and len(filename) > 0:
-                log.debug('Exporting XMI model to: %s' % filename)
-                export = exportmodel.XMIExport(self.element_factory)
-                try:
-                    export.export(filename)
-                except Exception, e:
-                    log.error('Error while saving model to file %s: %s' % (filename, e))
+        file_dialog = FileDialog(_('Export model to XMI file'),\
+                                 action='save',\
+                                 filename=filename)
+        
+        filename = file_dialog.selection
+        
+        if filename and len(filename) > 0:
+            log.debug('Exporting XMI model to: %s' % filename)
+            export = exportmodel.XMIExport(self.element_factory)
+            try:
+                export.export(filename)
+            except Exception, e:
+                log.error('Error while saving model to file %s: %s' % (filename, e))
 
 
 # vim:sw=4:et
