@@ -29,8 +29,9 @@ class CopyService(object):
 
     interface.implements(IService, IActionProvider)
 
+    component_registry = inject('component_registry')
     element_factory = inject('element_factory')
-    gui_manager = inject('gui_manager')
+    main_window = inject('main_window')
 
     menu_xml = """
       <ui>
@@ -50,15 +51,14 @@ class CopyService(object):
         self.action_group = build_action_group(self)
 
     def init(self, app):
-        self._app = app
         self.action_group.get_action('edit-copy').props.sensitive = False
         self.action_group.get_action('edit-paste').props.sensitive = False
         
-        app.register_handler(self._update)
+        self.component_registry.register_handler(self._update)
 
     def shutdown(self):
         self.copy_buffer = set()
-        self._app.unregister_handler(self._update)
+        self.component_registry.unregister_handler(self._update)
 
     @component.adapter(IDiagramSelectionChange)
     def _update(self, event):
@@ -140,7 +140,7 @@ class CopyService(object):
 
     @action(name='edit-copy', stock_id='gtk-copy')
     def copy_action(self):
-        view = self.gui_manager.main_window.get_current_diagram_view()
+        view = self.main_window.get_current_diagram_view()
         if view.is_focus():
             items = view.selected_items
             copy_items = []
@@ -150,8 +150,8 @@ class CopyService(object):
 
     @action(name='edit-paste', stock_id='gtk-paste')
     def paste_action(self):
-        view = self.gui_manager.main_window.get_current_diagram_view()
-        diagram = self.gui_manager.main_window.get_current_diagram()
+        view = self.main_window.get_current_diagram_view()
+        diagram = self.main_window.get_current_diagram()
         if not view:
             return
 
