@@ -1,12 +1,11 @@
-"""
-About and help services. (help browser anyone?)
-"""
-
+"""About and help services. (help browser anyone?)"""
 
+from logging import getLogger
 import os
 import pkg_resources
 import gtk
 from zope import interface
+
 from gaphor.application import Application
 from gaphor.interfaces import IService, IActionProvider
 from gaphor.core import _, inject, action, build_action_group
@@ -27,23 +26,25 @@ class HelpService(object):
       </ui>
     """
 
-    gui_manager = inject('gui_manager')
+    main_window = inject('main_window')
+    logger = getLogger('HelpService')
 
     def __init__(self):
         pass
 
     def init(self, app):
+        self.logger.info('Starting')
         self.action_group = build_action_group(self)
 
     def shutdown(self):
-        pass
+        self.logger.info('Shutting down')
 
     @action(name='help-about', stock_id='gtk-about')
     def about(self):
         logo_file =  os.path.join(pkg_resources.get_distribution('gaphor').location, 'gaphor', 'ui', 'pixmaps', 'logo.png')
         logo = gtk.gdk.pixbuf_new_from_file(logo_file)
         version = Application.distribution.version
-        about = gtk.Dialog("About Gaphor", self.gui_manager.main_window.window, gtk.DIALOG_MODAL, (gtk.STOCK_OK, gtk.RESPONSE_OK))
+        about = gtk.Dialog(_('About Gaphor'), self.main_window.window, gtk.DIALOG_MODAL, (gtk.STOCK_OK, gtk.RESPONSE_OK))
         about.set_default_response(gtk.RESPONSE_OK)
         vbox = about.vbox
 
@@ -53,7 +54,6 @@ class HelpService(object):
 
         notebook = gtk.Notebook()
         notebook.set_scrollable(True)
-        #notebook.set_show_border(False)
         notebook.set_border_width(4)
         notebook.set_tab_pos(gtk.POS_BOTTOM)
         vbox.pack_start(notebook)
@@ -67,12 +67,11 @@ class HelpService(object):
             label.set_justify(gtk.JUSTIFY_CENTER)
             tab_vbox.pack_start(label)
 
-        #add_label('<span size="xx-large" weight="bold">Gaphor</span>')
         add_label('<span weight="bold">version %s</span>' % version)
         add_label('<span variant="smallcaps">UML Modeling tool for GNOME</span>', 8, 8)
         add_label('<span size="small">Copyright (c) 2001-2007 Arjan J. Molenaar</span>', 8, 8)
-        #vbox.pack_start(gtk.HSeparator())
-        notebook.append_page(tab_vbox, gtk.Label('About'))
+
+        notebook.append_page(tab_vbox, gtk.Label(_('About')))
 
         tab_vbox = gtk.VBox()
         
@@ -80,7 +79,7 @@ class HelpService(object):
                   'under the terms of the\n'
                   '<span weight="bold">GNU General Public License v2</span>.\n'
                   'See the COPYING file for details.', 0, 8)
-        notebook.append_page(tab_vbox, gtk.Label('License'))
+        notebook.append_page(tab_vbox, gtk.Label(_('License')))
 
         tab_vbox = gtk.VBox()
         
@@ -89,7 +88,7 @@ class HelpService(object):
                   'Artur Wroblewski\n'
                   'Jeroen Vloothuis')
         add_label('')
-        notebook.append_page(tab_vbox, gtk.Label('Authors'))
+        notebook.append_page(tab_vbox, gtk.Label(_('Authors')))
 
         vbox.show_all()
         about.run()
