@@ -22,7 +22,7 @@ from gaphor.UML.collection import collection
 from gaphor.UML.elementfactory import ElementChangedEventBlocker
 from gaphor import diagram
 from gaphor.storage import parser
-from gaphor.application import Application
+from gaphor.application import Application, NotInitializedError
 from gaphor.diagram import items
 from gaphor.i18n import _
 #from gaphor.misc.xmlwriter import XMLWriter
@@ -47,8 +47,7 @@ def save(writer=None, factory=None, status_queue=None):
 def save_generator(writer, factory):
     """
     Save the current model using @writer, which is a
-    gaphor.misc.xmlwriter.XMLWriter instance (or at least a SAX serializer
-    with CDATA support).
+    gaphor.misc.xmlwriter.XMLWriter instance.
     """
 
     # Maintain a set of id's, one for elements, one for references.
@@ -84,15 +83,12 @@ def save_generator(writer, factory):
     def save_value(name, value):
         """
         Save a value (attribute).
-        If the value is a string, it is saves as a CDATA block.
         """
         if value is not None:
             writer.startElement(name, {})
             writer.startElement('val', {})
             if isinstance(value, types.StringTypes):
-                writer.startCDATA()
                 writer.characters(value)
-                writer.endCDATA()
             elif isinstance(value, bool):
                 # Write booleans as 0/1.
                 writer.characters(str(int(value)))
@@ -200,6 +196,7 @@ def load_elements_generator(elements, factory, gaphor_version=None):
     version_0_9_0(elements, factory, gaphor_version)
     version_0_14_0(elements, factory, gaphor_version)
     version_0_15_0_pre(elements, factory, gaphor_version)
+    version_0_17_0(elements, factory, gaphor_version)
 
     #log.debug("Still have %d elements" % len(elements))
 
@@ -246,7 +243,7 @@ def load_elements_generator(elements, factory, gaphor_version=None):
                 raise
 
         for name, refids in elem.references.items():
-            if type(refids) == type([]):
+            if type(refids) == list:
                 for refid in refids:
                     try:
                         ref = elements[refid]
@@ -305,7 +302,6 @@ def load(filename, factory, status_queue=None):
     Load a file and create a model if possible.
     Optionally, a status queue function can be given, to which the
     progress is written (as status_queue(progress)).
-    Exceptions: GaphorError.
     """
     for status in load_generator(filename, factory):
         if status_queue:
@@ -316,8 +312,6 @@ def load_generator(filename, factory):
     Load a file and create a model if possible.
     This function is a generator. It will yield values from 0 to 100 (%)
     to indicate its progression.
-
-    Exceptions: GaphorError.
     """
     if isinstance(filename, (file, InputType)):
         log.info('Loading file from file descriptor')
@@ -337,14 +331,20 @@ def load_generator(filename, factory):
         #elements = parser.parse(filename)
         #yield 100
     except Exception, e:
-        log.error('File could no be parsed', e)
+        log.error('File could no be parsed', exc_info=True)
         raise
 
+    try:
+        component_registry = Application.get_service('component_registry')
+    except NotInitializedError:
+        component_registry = None
+
     try:
         factory.flush()
         gc.collect()
         log.info("Read %d elements from file" % len(elements))
-        Application.register_subscription_adapter(ElementChangedEventBlocker)
+        if component_registry:
+            component_registry.register_subscription_adapter(ElementChangedEventBlocker)
         try:
             for percentage in load_elements_generator(elements, factory, gaphor_version):
                 if percentage:
@@ -352,13 +352,15 @@ def load_generator(filename, factory):
                 else:
                     yield percentage
         except Exception, e:
-            Application.unregister_subscription_adapter(ElementChangedEventBlocker)
             raise
-        Application.unregister_subscription_adapter(ElementChangedEventBlocker)
+        finally:
+            if component_registry:
+                component_registry.unregister_subscription_adapter(ElementChangedEventBlocker)
+
         gc.collect()
         yield 100
     except Exception, e:
-        log.info('file %s could not be loaded' % filename, e)
+        log.info('file %s could not be loaded' % filename)
         raise
 
 def version_lower_than(gaphor_version, version):
@@ -370,9 +372,9 @@ def version_lower_than(gaphor_version, version):
     try:
         return tuple(map(int, parts)) < version
     except ValueError:
-        # We're having a -pre, -beta, -alpha or whatever version
+        # We're having a -dev, -pre, -beta, -alpha or whatever version
         parts = parts[:-1]
-        return tuple(map(int, parts)) <= version
+        return tuple(map(int, parts)) <= version 
     
 
 def version_0_15_0_pre(elements, factory, gaphor_version):
@@ -518,7 +520,7 @@ def version_0_15_0_post(elements, factory, gaphor_version):
                                 log.info('Special case: UML metamodel "%s %s"' % (key, val))
                         create_slot(key, val)
                     except Exception, e:
-                        log.warning('Unable to process tagged value "%s" as key=value pair' % tv, e)
+                        log.warning('Unable to process tagged value "%s" as key=value pair' % tv, exc_info=True)
 
         def find(messages, attr):
             occurrences = set(getattr(m, attr) for m in messages
@@ -611,6 +613,36 @@ def convert_tagged_value(element, elements, factory):
                     d.canvas.canvasitems.append(item)
                     break
 
+def version_0_17_0(elements, factory, gaphor_version):
+    """
+    As of version 0.17.0, ValueSpecification and subclasses is dealt
+    with as if it were attributes.
+
+    This function is called before the actual elements are constructed.
+    """
+    valspec_types = [ 'ValueSpecification', 'OpaqueExpression', 'Expression',
+        'InstanceValue', 'LiteralSpecification', 'LiteralUnlimitedNatural',
+        'LiteralInteger', 'LiteralString', 'LiteralBoolean', 'LiteralNull' ]
+    
+    print 'version', gaphor_version
+    if version_lower_than(gaphor_version, (0, 17, 0)):
+        valspecs = dict((v.id, v) for v in elements.values() if v.type in valspec_types)
+
+        for id in valspecs.keys():
+            del elements[id]
+
+        for e in elements.values():
+            for name, ref in list(e.references.items()):
+                # ValueSpecifications are always defined in 1:1 relationships
+                if type(ref) != list and ref in valspecs:
+                    del e.references[name]
+                    assert not name in e.values
+                    try:
+                        e.values[name] = valspecs[ref].values['value'];
+                    except KeyError:
+                        pass # Empty LiteralSpecification
+
+
 def version_0_14_0(elements, factory, gaphor_version):
     """
     Fix applied stereotypes UML metamodel. Before Gaphor 0.14.0 applied
@@ -643,7 +675,7 @@ def version_0_14_0(elements, factory, gaphor_version):
                     et.references['appliedStereotype'] = applied
 
             except Exception, e:
-                log.error('Error while updating stereotypes', e)
+                log.error('Error while updating stereotypes', exc_info=True)
 
 
 def version_0_9_0(elements, factory, gaphor_version):
@@ -667,7 +699,7 @@ def version_0_9_0(elements, factory, gaphor_version):
                         del elem.values['color']
 
             except Exception, e:
-                log.error('Error while updating from DiaCanvas2', e)
+                log.error('Error while updating from DiaCanvas2', exc_info=True)
 
 def version_0_7_2(elements, factory, gaphor_version):
     """
@@ -696,7 +728,7 @@ def version_0_7_2(elements, factory, gaphor_version):
                             tvlist.append(newtv.id)
                         elem.references['taggedValue'] = tvlist
             except Exception, e:
-                log.error('Error while updating taggedValues', e)
+                log.error('Error while updating taggedValues', exc_info=True)
 
 
 def version_0_7_1(elements, factory, gaphor_version):
@@ -732,7 +764,7 @@ def version_0_7_1(elements, factory, gaphor_version):
                         fix(end1, end2)
                         fix(end2, end1)
             except Exception, e:
-                log.error('Error while updating Association', e)
+                log.error('Error while updating Association', exc_info=True)
 
 
 def version_0_6_2(elements, factory, gaphor_version):
@@ -752,7 +784,7 @@ def version_0_6_2(elements, factory, gaphor_version):
                         elif p.type == 'InterfaceItem':
                             p.values['drawing-style'] = '2'
             except Exception, e:
-                log.error('Error while updating InterfaceItems', e)
+                log.error('Error while updating InterfaceItems', exc_info=True)
 
 
 def version_0_5_2(elements, factory, gaphor_version):
@@ -771,7 +803,7 @@ def version_0_5_2(elements, factory, gaphor_version):
                     a.memberEnd[0].aggregation = agg2
                     a.memberEnd[1].aggregation = agg1
             except Exception, e:
-                log.error('Error while updating Association', e)
+                log.error('Error while updating Association', exc_info=True)
 
 
 # vim: sw=4:et:ai
