@@ -3,6 +3,8 @@ Unittest the storage and parser modules
 """
 
 import os, re
+import os.path
+import pkg_resources
 from gaphor.tests.testcase import TestCase
 from gaphor import UML
 from gaphor.UML.elementfactory import ElementFactory
@@ -139,15 +141,28 @@ class StorageTestCase(TestCase):
         assert d1
         #print d1, d1.subject
 
+    def test_load_with_whitespace_name(self):
+        difficult_name = '    with space before and after  '
+        diagram = self.element_factory.lselect()[0]
+        diagram.name = difficult_name
+        data = self.save()
+        self.load(data)
+        elements = self.element_factory.lselect()
+        assert len(elements) == 1, elements
+        assert elements[0].name == difficult_name, elements[0].name
+
+
     def test_load_uml_metamodel(self):
         """
         Test if the meta model can be loaded.
         """
-        try:
-            f = open('gaphor/UML/uml2.gaphor')
-            storage.load(f, factory=self.element_factory)
-        finally:
-            f.close()
+        
+        dist = pkg_resources.get_distribution('gaphor')
+        path = os.path.join(dist.location, 'gaphor/UML/uml2.gaphor')
+        
+        with open(path) as ifile:
+            
+            storage.load(ifile, factory=self.element_factory)
 
     def test_load_uml_relationships(self):
         """
@@ -240,38 +255,48 @@ class StorageTestCase(TestCase):
         #assert a.head_end._name
 
     def test_load_save(self):
-        f = open('test-diagrams/simple-items.gaphor', 'r')
-        storage.load(f, factory=self.element_factory)
-        f.close()
-
+        
+        """Test loading and saving models"""
+        
+        dist = pkg_resources.get_distribution('gaphor')
+        path = os.path.join(dist.location, 'test-diagrams/simple-items.gaphor')
+        
+        with open(path, 'r') as ifile:
+            
+            storage.load(ifile, factory=self.element_factory)
+            
         pf = PseudoFile()
+        
         storage.save(XMLWriter(pf), factory=self.element_factory)
 
-        f = open('test-diagrams/simple-items.gaphor', 'r')
-        orig = f.read()
-        f.close()
-
+        with open(path, 'r') as ifile:
+            
+            orig = ifile.read()
+            
         copy = pf.data
 
+        with open('tmp.gaphor', 'w') as ofile:
+            
+            ofile.write(copy)
+            
         expr = re.compile('gaphor-version="[^"]*"')
         orig = expr.sub('%VER%', orig)
         copy = expr.sub('%VER%', copy)
 
-        f = open('tmp.gaphor', 'w')
-        f.write(copy)
-        f.close()
-
-
-        self.assertEquals(copy, orig)
+        self.assertEquals(copy, orig, 'Saved model does not match copy')
 
 
 class FileUpgradeTestCase(TestCase):
     def test_association_upgrade(self):
         """Test association navigability upgrade in Gaphor 0.15.0
         """
-        f = open('test-diagrams/associations-pre015.gaphor')
-        storage.load(f, factory=self.element_factory)
-        f.close()
+        
+        dist = pkg_resources.get_distribution('gaphor')
+        path = os.path.join(dist.location, 'test-diagrams/associations-pre015.gaphor')
+        
+        with open(path) as ifile:
+            
+            storage.load(ifile, factory=self.element_factory)
 
         diagrams = list(self.kindof(UML.Diagram))
         self.assertEquals(1, len(diagrams))
@@ -322,10 +347,14 @@ class FileUpgradeTestCase(TestCase):
     def test_tagged_values_upgrade(self):
         """Test tagged values upgrade in Gaphor 0.15.0
         """
-        f = open('test-diagrams/taggedvalues-pre015.gaphor')
-        storage.load(f, factory=self.element_factory)
-        f.close()
-
+        
+        dist = pkg_resources.get_distribution('gaphor')
+        path = os.path.join(dist.location, 'test-diagrams/taggedvalues-pre015.gaphor')
+        
+        with open(path) as ifile:
+            
+            storage.load(ifile, factory=self.element_factory)
+                    
         diagrams = list(self.kindof(UML.Diagram))
         self.assertEquals(1, len(diagrams))
         diagram = diagrams[0]
@@ -358,9 +387,13 @@ class FileUpgradeTestCase(TestCase):
     def test_lifeline_messages_upgrade(self):
         """Test message occurrence specification upgrade in Gaphor 0.15.0
         """
-        f = open('test-diagrams/lifelines-pre015.gaphor')
-        storage.load(f, factory=self.element_factory)
-        f.close()
+
+        dist = pkg_resources.get_distribution('gaphor')
+        path = os.path.join(dist.location, 'test-diagrams/lifelines-pre015.gaphor')
+        
+        with open(path) as ifile:
+            
+            storage.load(ifile, factory=self.element_factory)        
 
         diagrams = list(self.kindof(UML.Diagram))
         self.assertEquals(1, len(diagrams))
