@@ -6,18 +6,15 @@ main screen and diagram windows.
 import os, os.path
 import gtk
 
-if os.name == 'nt':
-    home = 'USERPROFILE'
-else:
-    home = 'HOME'
-
-user_data_dir = os.path.join(os.getenv(home), '.gaphor')
-
+from gaphor.misc import get_user_data_dir
 
 def _get_accel_map_filename():
     """
     The Gaphor accelMap file ($HOME/.gaphor/accelmap).
     """
+    
+    user_data_dir = get_user_data_dir()
+    
     if not os.path.exists(user_data_dir):
         os.mkdir(user_data_dir)
     return os.path.join(user_data_dir, 'accelmap')
