@@ -11,66 +11,68 @@ from gaphor.UML.event import DiagramItemCreateEvent
 from gaphor import UML
 from gaphor.diagram import items
 from gaphor.core import _, inject, radio_action, build_action_group
-from diagramtools import PlacementTool, DefaultTool
-from groupingtools import GroupPlacementTool
+from diagramtools import PlacementTool, GroupPlacementTool, DefaultTool
 from gaphas.item import SE
 
 __all__ = [ 'DiagramToolbox', 'TOOLBOX_ACTIONS' ]
 
+# Actions: ((section (name, label, stock_id, shortcut)), ...)
 TOOLBOX_ACTIONS = (
     ('', (
-        ('toolbox-pointer', _('Pointer'), 'gaphor-pointer'),
-        ('toolbox-line', _('Line'), 'gaphor-line'),
-        ('toolbox-box', _('Box'), 'gaphor-box'),
-        ('toolbox-ellipse', _('Ellipse'), 'gaphor-ellipse'),
-        ('toolbox-comment', _('Comment'), 'gaphor-comment'),
-        ('toolbox-comment-line', _('Comment line'), 'gaphor-comment-line'),
+        ('toolbox-pointer', _('Pointer'), 'gaphor-pointer', 'Escape'),
+        ('toolbox-line', _('Line'), 'gaphor-line', 'l'),
+        ('toolbox-box', _('Box'), 'gaphor-box', 'b'),
+        ('toolbox-ellipse', _('Ellipse'), 'gaphor-ellipse', 'e'),
+        ('toolbox-comment', _('Comment'), 'gaphor-comment', 'k'),
+        ('toolbox-comment-line', _('Comment line'), 'gaphor-comment-line', 'K'),
     )), (_('Classes'), (
-        ('toolbox-class', _('Class'), 'gaphor-class'),
-        ('toolbox-interface', _('Interface'), 'gaphor-interface'),
-        ('toolbox-package', _('Package'), 'gaphor-package'),
-        ('toolbox-association', _('Association'), 'gaphor-association'),
-        ('toolbox-dependency', _('Dependency'), 'gaphor-dependency'),
-        ('toolbox-generalization', _('Generalization'), 'gaphor-generalization'),
-        ('toolbox-implementation', _('Implementation'), 'gaphor-implementation'),
+        ('toolbox-class', _('Class'), 'gaphor-class', 'c'),
+        ('toolbox-interface', _('Interface'), 'gaphor-interface', 'i'),
+        ('toolbox-package', _('Package'), 'gaphor-package', 'p'),
+        ('toolbox-association', _('Association'), 'gaphor-association', 'A'),
+        ('toolbox-dependency', _('Dependency'), 'gaphor-dependency', 'D'),
+        ('toolbox-generalization', _('Generalization'), 'gaphor-generalization', 'G'),
+        ('toolbox-implementation', _('Implementation'), 'gaphor-implementation', 'I'),
     )), (_('Components'), (
-        ('toolbox-component', _('Component'), 'gaphor-component'),
-        ('toolbox-artifact', _('Artifact'), 'gaphor-artifact'),
-        ('toolbox-node', _('Node'), 'gaphor-node'),
-        ('toolbox-device', _('Device'), 'gaphor-device'),
-        ('toolbox-subsystem', _('Subsystem'), 'gaphor-subsystem'),
-        ('toolbox-connector', _('Connector'), 'gaphor-connector'),
+        ('toolbox-component', _('Component'), 'gaphor-component', 'o'),
+        ('toolbox-artifact', _('Artifact'), 'gaphor-artifact', 'h'),
+        ('toolbox-node', _('Node'), 'gaphor-node', 'n'),
+        ('toolbox-device', _('Device'), 'gaphor-device', 'd'),
+        ('toolbox-subsystem', _('Subsystem'), 'gaphor-subsystem', 'y'),
+        ('toolbox-connector', _('Connector'), 'gaphor-connector', 'C'),
     )), (_('Actions'), (
-        ('toolbox-action', _('Action'), 'gaphor-action'),
-        ('toolbox-initial-node', _('Initial node'), 'gaphor-initial-node'),
-        ('toolbox-activity-final-node', _('Activity final node'), 'gaphor-activity-final-node'),
-        ('toolbox-flow-final-node', _('Flow final node'), 'gaphor-flow-final-node'),
-        ('toolbox-decision-node', _('Decision/merge node'), 'gaphor-decision-node'),
-        ('toolbox-fork-node', _('Fork/join node'), 'gaphor-fork-node'),
-        ('toolbox-object-node', _('Object node'), 'gaphor-object-node'),
-        ('toolbox-partition', _('Partition'), 'gaphor-partition'),
-        ('toolbox-flow', _('Control/object flow'), 'gaphor-control-flow'),
+        ('toolbox-action', _('Action'), 'gaphor-action', 'a'),
+        ('toolbox-initial-node', _('Initial node'), 'gaphor-initial-node', 'j'),
+        ('toolbox-activity-final-node', _('Activity final node'), 'gaphor-activity-final-node', 'f'),
+        ('toolbox-flow-final-node', _('Flow final node'), 'gaphor-flow-final-node', 'w'),
+        ('toolbox-decision-node', _('Decision/merge node'), 'gaphor-decision-node', 'g'),
+        ('toolbox-fork-node', _('Fork/join node'), 'gaphor-fork-node', 'R'),
+        ('toolbox-object-node', _('Object node'), 'gaphor-object-node', 'O'),
+        ('toolbox-partition', _('Partition'), 'gaphor-partition', 'P'),
+        ('toolbox-flow', _('Control/object flow'), 'gaphor-control-flow', 'F'),
+        ('toolbox-send-signal-action', _('Send signal action'), 'gaphor-send-signal-action', None),
+        ('toolbox-accept-event-action', _('Accept event action'), 'gaphor-accept-event-action', None),
     )), (_('Interactions'), (
-        ('toolbox-lifeline', _('Lifeline'), 'gaphor-lifeline'),
-        ('toolbox-message', _('Message'), 'gaphor-message'),
-        ('toolbox-interaction', _('Interaction'), 'gaphor-interaction'),
+        ('toolbox-lifeline', _('Lifeline'), 'gaphor-lifeline', 'v'),
+        ('toolbox-message', _('Message'), 'gaphor-message', 'M'),
+        ('toolbox-interaction', _('Interaction'), 'gaphor-interaction', 'N'),
     )), (_('States'), (
-        ('toolbox-state', _('State'), 'gaphor-state'),
-        ('toolbox-initial-pseudostate', _('Initial Pseudostate'), 'gaphor-initial-pseudostate'),
-        ('toolbox-final-state', _('Final State'), 'gaphor-final-state'),
-        ('toolbox-history-pseudostate', _('History Pseudostate'), 'gaphor-history-pseudostate'),
-        ('toolbox-transition', _('Transition'), 'gaphor-transition'),
+        ('toolbox-state', _('State'), 'gaphor-state', 's'),
+        ('toolbox-initial-pseudostate', _('Initial Pseudostate'), 'gaphor-initial-pseudostate', 'S'),
+        ('toolbox-final-state', _('Final State'), 'gaphor-final-state', 'x'),
+        ('toolbox-history-pseudostate', _('History Pseudostate'), 'gaphor-history-pseudostate', 'q'),
+        ('toolbox-transition', _('Transition'), 'gaphor-transition', 'T'),
     )), (_('Use Cases'), (
-        ('toolbox-usecase', _('Use case'), 'gaphor-usecase'),
-        ('toolbox-actor', _('Actor'), 'gaphor-actor'),
-        ('toolbox-usecase-association', _('Association'), 'gaphor-association'),
-        ('toolbox-include', _('Include'), 'gaphor-include'),
-        ('toolbox-extend', _('Extend'), 'gaphor-extend'),
+        ('toolbox-usecase', _('Use case'), 'gaphor-usecase', 'u'),
+        ('toolbox-actor', _('Actor'), 'gaphor-actor', 't'),
+        ('toolbox-usecase-association', _('Association'), 'gaphor-association', 'B'),
+        ('toolbox-include', _('Include'), 'gaphor-include', 'U'),
+        ('toolbox-extend', _('Extend'), 'gaphor-extend', 'X'),
     )), (_('Profiles'), (
-        ('toolbox-profile', _('Profile'), 'gaphor-profile'),
-        ('toolbox-metaclass', _('Metaclass'), 'gaphor-metaclass'),
-        ('toolbox-stereotype', _('Stereotype'), 'gaphor-stereotype'),
-        ('toolbox-extension', _('Extension'), 'gaphor-extension'),
+        ('toolbox-profile', _('Profile'), 'gaphor-profile', 'r'),
+        ('toolbox-metaclass', _('Metaclass'), 'gaphor-metaclass', 'm'),
+        ('toolbox-stereotype', _('Stereotype'), 'gaphor-stereotype', 'z'),
+        ('toolbox-extension', _('Extension'), 'gaphor-extension', 'E'),
     )),
     )
 
@@ -289,6 +291,20 @@ class DiagramToolbox(object):
                 handle_index=SE,
                 after_handler=self._after_handler)
 
+    def toolbox_send_signal_action(self):
+        return GroupPlacementTool(self.view,
+                item_factory=self._namespace_item_factory(items.SendSignalActionItem,
+                                                          UML.SendSignalAction),
+                handle_index=SE,
+                after_handler=self._after_handler)
+
+    def toolbox_accept_event_action(self):
+        return GroupPlacementTool(self.view,
+                item_factory=self._namespace_item_factory(items.AcceptEventActionItem,
+                                                          UML.AcceptEventAction),
+                handle_index=SE,
+                after_handler=self._after_handler)
+
     def toolbox_initial_node(self):
         return GroupPlacementTool(self.view,
                 item_factory=self._item_factory(items.InitialNodeItem,
