@@ -8,18 +8,26 @@ Although Gaphas has quite a few useful tools, some tools need to be extended:
 """
 
 import gtk
-from cairo import Matrix
 from zope import component
 
 from gaphas.geometry import distance_point_point, distance_point_point_fast, \
                             distance_line_point, distance_rectangle_point
 from gaphas.tool import Tool, HandleTool, PlacementTool as _PlacementTool, \
     ToolChain, HoverTool, ItemTool, RubberbandTool, ConnectHandleTool
-from gaphas.aspect import Connector
+from gaphas.aspect import Connector, InMotion
+from gaphas.guide import GuidedItemInMotion
 from gaphor.core import inject, Transaction, transactional
 
-from gaphor.diagram.interfaces import IEditor, IConnect
+from gaphor.diagram.interfaces import IEditor, IConnect, IGroup
 from gaphor.diagram.diagramline import DiagramLine
+from gaphor.diagram.elementitem import ElementItem
+
+
+# cursor to indicate grouping
+IN_CURSOR = gtk.gdk.Cursor(gtk.gdk.DIAMOND_CROSS)
+
+# cursor to indicate ungrouping
+OUT_CURSOR = gtk.gdk.Cursor(gtk.gdk.SIZING)
 
 
 @Connector.when_type(DiagramLine)
@@ -31,6 +39,7 @@ class DiagramItemConnector(Connector.default):
     It also adds handles to lines when a line is grabbed on the middle of
     a line segment (points are drawn by the LineSegmentPainter).
     """
+
     def allow(self, sink):
         adapter = component.queryMultiAdapter((sink.item, self.item), IConnect)
         return adapter and adapter.allow(self.handle, sink.port)
@@ -52,47 +61,30 @@ class DiagramItemConnector(Connector.default):
                 log.debug('performing reconnect constraint')
                 constraint = sink.port.constraint(item.canvas, item, handle, sink.item)
                 item.canvas.reconnect_item(item, handle, constraint=constraint)
-            else:
-                if cinfo:
-                    # first disconnect but disable disconnection handle as
-                    # reconnection is going to happen
-                    adapter = component.queryMultiAdapter((sink.item, item), IConnect)
-                    if adapter and adapter.CAN_RECONNECT:
-                        cinfo.callback.disable = True
-                    self.disconnect()
+            elif cinfo:
+                # first disconnect but disable disconnection handle as
+                # reconnection is going to happen
+                adapter = component.queryMultiAdapter((sink.item, item), IConnect)
+                try:
+                    connect = adapter.reconnect
+                except AttributeError:
+                    connect = adapter.connect
+                else:
+                    cinfo.callback.disable = True
+                self.disconnect()
+
                 # new connection
                 self.connect_handle(sink, callback=callback)
+
                 # adapter requires both ends to be connected.
-                reconnect = cinfo is not None
-                self.model_connect(sink, reconnect)
+                connect(handle, sink.port)
+            else:
+                # new connection
+                adapter = component.queryMultiAdapter((sink.item, item), IConnect)
+                self.connect_handle(sink, callback=callback)
+                adapter.connect(handle, sink.port)
         except Exception, e:
-            log.error('Error during connect', e)
-
-
-    def model_connect(self, sink, reconnect):
-        """
-        Connecting requires the handles to be connected before the model
-        level connection is made.
-
-        Note that once this method is called, the glue() method has done that
-        for us.
-        """
-        handle = self.handle
-        item = self.item
-
-        adapter = component.queryMultiAdapter((sink.item, item), IConnect)
-        log.debug('Connect on model level ' + str(adapter))
-
-        assert adapter is not None
-        assert handle in adapter.line.handles()
-        assert sink.port in adapter.element.ports()
-
-        if reconnect and adapter.CAN_RECONNECT:
-            log.debug('Performing reconnection')
-            adapter.reconnect(handle, sink.port)
-        else:
-            log.debug('Performing connection')
-            adapter.connect(handle, sink.port)
+            log.error('Error during connect', exc_info=True)
 
 
     @transactional
@@ -248,6 +240,7 @@ class PlacementTool(_PlacementTool):
         return self._create_item(pos)
 
     def on_button_press(self, event):
+        assert not self._tx
         self._tx = Transaction()
         view = self.view
         view.unselect_all()
@@ -282,7 +275,156 @@ class PlacementTool(_PlacementTool):
             self._tx = None
 
 
+class GroupPlacementTool(PlacementTool):
+    """
+    Try to group items when placing them on diagram.
+    """
 
+    def __init__(self, view, item_factory, after_handler=None, handle_index=-1):
+        super(GroupPlacementTool, self).__init__(view,
+                item_factory, after_handler, handle_index)
+        self._parent = None
+
+
+    def on_motion_notify(self, event):
+        """
+        Change parent item to dropzone state if it can accept diagram item
+        object to be created.
+        """
+        view = self.view
+
+        if view.focused_item:
+            view.unselect_item(view.focused_item)
+            view.focused_item = None
+
+        try:
+            parent = view.get_item_at_point((event.x, event.y))
+        except KeyError:
+            parent = None
+
+        if parent:
+            # create dummy adapter
+            adapter = component.queryMultiAdapter((parent, self._factory.item_class()), IGroup)
+            if adapter and adapter.can_contain():
+                view.dropzone_item = parent
+                view.window.set_cursor(IN_CURSOR)
+                self._parent = parent
+            else:
+                view.dropzone_item = None
+                view.window.set_cursor(None)
+                self._parent = None
+            parent.request_update(matrix=False)
+        else:
+            if view.dropzone_item:
+                view.dropzone_item.request_update(matrix=False)
+            view.dropzone_item = None
+            view.window.set_cursor(None)
+
+
+    def _create_item(self, pos, **kw):
+        """
+        Create diagram item and place it within parent's boundaries.
+        """
+        parent = self._parent
+        view = self.view
+        try:
+            adapter = component.queryMultiAdapter((parent, self._factory.item_class()), IGroup)
+            if parent and adapter and adapter.can_contain():
+                kw['parent'] = parent
+
+            item = super(GroupPlacementTool, self)._create_item(pos, **kw)
+
+            adapter = component.queryMultiAdapter((parent, item), IGroup)
+            if parent and item and adapter:
+                adapter.group()
+
+                canvas = view.canvas
+                parent.request_update(matrix=False)
+        finally:
+            self._parent = None
+            view.dropzone_item = None
+            view.window.set_cursor(None)
+        return item
+
+
+@InMotion.when_type(ElementItem)
+class DropZoneInMotion(GuidedItemInMotion):
+
+
+    def move(self, pos):
+        """
+        Move the item. x and y are in view coordinates.
+        """
+        super(DropZoneInMotion, self).move(pos)
+        item = self.item
+        view = self.view
+        x, y = pos
+
+        current_parent = view.canvas.get_parent(item)
+        over_item = view.get_item_at_point((x, y), selected=False)
+
+        if not over_item:
+            view.dropzone_item = None
+            view.window.set_cursor(None)
+            return
+
+        if current_parent and not over_item:  # are we going to remove from parent?
+            adapter = component.queryMultiAdapter((current_parent, item), IGroup)
+            if adapter:
+                view.window.set_cursor(OUT_CURSOR)
+                view.dropzone_item = current_parent
+                current_parent.request_update(matrix=False)
+
+        if over_item:
+            # are we going to add to parent?
+            adapter = component.queryMultiAdapter((over_item, item), IGroup)
+            if adapter and adapter.can_contain():
+                view.dropzone_item = over_item
+                view.window.set_cursor(IN_CURSOR)
+                over_item.request_update(matrix=False)
+
+
+    def stop_move(self):
+        """
+        Motion stops: drop!
+        """
+        super(DropZoneInMotion, self).stop_move()
+        item = self.item
+        view = self.view
+        canvas = view.canvas
+        old_parent = view.canvas.get_parent(item)
+        new_parent = view.dropzone_item
+        try:
+
+            if new_parent is old_parent:
+                if old_parent is not None:
+                    old_parent.request_update(matrix=False)
+                return
+
+            if old_parent:
+                adapter = component.queryMultiAdapter((old_parent, item), IGroup)
+                if adapter:
+                    adapter.ungroup()
+
+                canvas.reparent(item, None)
+                m = canvas.get_matrix_i2c(old_parent)
+                item.matrix *= m
+                old_parent.request_update()
+
+            if new_parent:
+                adapter = component.queryMultiAdapter((new_parent, item), IGroup)
+                if adapter and adapter.can_contain():
+                    adapter.group()
+
+                canvas.reparent(item, new_parent)
+                m = canvas.get_matrix_c2i(new_parent)
+                item.matrix *= m
+                new_parent.request_update()
+        finally:
+            view.dropzone_item = None
+            view.window.set_cursor(None)
+
+    
 class TransactionalToolChain(ToolChain):
     """
     In addition to a normal toolchain, this chain begins an undo-transaction
@@ -294,7 +436,10 @@ class TransactionalToolChain(ToolChain):
         self._tx = None
 
     def handle(self, event):
-        if self.EVENT_HANDLERS.get(event.type) in ('on_button_press', 'on_double_click', 'on_triple_click'):
+        # For double click: button_press, double_click, button_release
+        #print 'event', self.EVENT_HANDLERS.get(event.type)
+        if self.EVENT_HANDLERS.get(event.type) in ('on_button_press',):
+            assert not self._tx
             self._tx = Transaction()
 
         try:
@@ -309,12 +454,10 @@ def DefaultTool():
     """
     The default tool chain build from HoverTool, ItemTool and HandleTool.
     """
-    from gaphor.ui.groupingtools import GroupItemTool
-
     chain = TransactionalToolChain()
     chain.append(HoverTool())
     chain.append(ConnectHandleTool())
-    chain.append(GroupItemTool())
+    chain.append(ItemTool())
     chain.append(TextEditTool())
     chain.append(RubberbandTool())
     return chain
