@@ -5,6 +5,14 @@ Interfaces related to the user interface.
 from zope import interface
 
 
+class IDiagramTabChange(interface.Interface):
+    """
+    The selected diagram changes.
+    """
+    item = interface.Attribute('The newly selected DockItem')
+
+    diagram_tab = interface.Attribute('The newly selected diagram tab')
+
 class IDiagramSelectionChange(interface.Interface):
     """
     The selection of a diagram changed.
@@ -18,15 +26,28 @@ class IDiagramSelectionChange(interface.Interface):
 
 class IUIComponent(interface.Interface):
     """
-    A user interface component
+    A user interface component.
     """
     
-    ui_manager = interface.Attribute("The gtk.UIManager, set after construction")
-    def construct(self):
+    ui_name = interface.Attribute('The UIComponent name, provided by the loader')
+
+    title = interface.Attribute('Title of the component')
+
+    size = interface.Attribute('Size used for floating the component')
+
+    placement = interface.Attribute('placement. E.g. ("left", "diagrams")')
+
+    def open(self):
         """
         Create and display the UI components (windows).
         """
 
+    def close(self):
+        """
+        Close the UI component. The component can decide to hide or destroy the UI
+        components.
+        """
+
 
 class IPropertyPage(interface.Interface):
     """
@@ -48,4 +69,4 @@ class IPropertyPage(interface.Interface):
         """
 
 
-# vim:sw=4:et
+# vim:sw=4:et:ai
