@@ -4,14 +4,12 @@ from gaphor.tests.testcase import TestCase
 
 class ElementEditorTestCase(TestCase):
 
-    services = TestCase.services + ['gui_manager', 'action_manager', 'properties']
+    services = TestCase.services + ['main_window', 'ui_manager', 'action_manager', 'properties']
 
     def test1(self):
         import gtk
-        ui_manager = gtk.UIManager()
         window = ElementEditor()
-        window.ui_manager = ui_manager
         assert len(window.action_group.list_actions()) == 1, window.action_group.list_actions()
-        window.construct()
+        window.open()
         window.close()
 
