@@ -28,9 +28,9 @@ class Toolbox(gtk.VBox):
     TARGET_STRING = 0
     TARGET_TOOLBOX_ACTION = 1
     DND_TARGETS = [
-        ('STRING', 0, TARGET_STRING),
-        ('text/plain', 0, TARGET_STRING),
-        ('gaphor/toolbox-action', 0, TARGET_TOOLBOX_ACTION)]
+        ('STRING', gtk.TARGET_SAME_APP, TARGET_STRING),
+        ('text/plain', gtk.TARGET_SAME_APP, TARGET_STRING),
+        ('gaphor/toolbox-action', gtk.TARGET_SAME_APP, TARGET_TOOLBOX_ACTION)]
 
     __gsignals__ = {
         'toggled': (gobject.SIGNAL_RUN_FIRST,
@@ -46,10 +46,9 @@ class Toolbox(gtk.VBox):
         using the menu_factory and based on the toolboxdef definition.
         """
         self.__gobject_init__()
-        self.toolboxdef = toolboxdef
-        #self.boxes = []
         self.buttons = []
-        self._construct()
+        self.shortcuts = {}
+        self._construct(toolboxdef)
 
 
     def make_wrapbox_decorator(self, title, content):
@@ -103,16 +102,18 @@ class Toolbox(gtk.VBox):
         return button
 
 
-    def _construct(self):
-        for title, items in self.toolboxdef:
+    def _construct(self, toolboxdef):
+        shortcuts = self.shortcuts
+        for title, items in toolboxdef:
             wrapbox = Wrapbox()
-            for action_name, label, stock_id in items:
+            for action_name, label, stock_id, shortcut in items:
                 button = self.toolbox_button(action_name, stock_id)
                 if label:
-                    button.set_tooltip_text(label)
+                    button.set_tooltip_text('%s (%s)' % (label, shortcut))
                 self.buttons.append(button)
                 wrapbox.add(button)
                 button.show()
+                shortcuts[shortcut] = action_name
             if title:
                 wrapbox_dec = self.make_wrapbox_decorator(title, wrapbox)
                 self.pack_start(wrapbox_dec, expand=False)
