@@ -6,7 +6,8 @@ import os.path
 import pkg_resources
 
 import gtk
-
+from etk.docking import DockGroup, DockItem
+from etk.docking.docklayout import add_new_group_floating
 from zope import interface
 from interfaces import IUIComponent
 from gaphor.core import inject
@@ -30,6 +31,9 @@ class ToplevelWindow(object):
     def __init__(self):
         self.window = None
 
+    def ui_component(self):
+        raise NotImplementedError
+
     def construct(self):
 
         self.window = gtk.Window(gtk.WINDOW_TOPLEVEL)
@@ -68,22 +72,4 @@ class ToplevelWindow(object):
         self.window.show()
 
 
-class UtilityWindow(ToplevelWindow):
-
-    gui_manager = inject('gui_manager')
-
-    resizable = False
-
-    def construct(self):
-        super(UtilityWindow, self).construct()
-
-        main_window = self.gui_manager.main_window.window
-        self.window.set_transient_for(main_window)
-        #self.window.set_keep_above(True)
-        self.window.set_property('skip-taskbar-hint', True)
-        self.window.set_position(gtk.WIN_POS_MOUSE)
-        self.window.show()
-       #self.window.set_type_hint(gtk.gdk.WINDOW_TYPE_HINT_UTILITY)
-
-
 # vim:sw=4:et:ai
